Chaos and Fractals\

Chaos and Fractals\
Mark McClure\
University of North Carolina at Asheville\
August 15, 2021\

PrefacePrefaceg:preface:idp140253883007352 This is an introductory text
on the basics of chaotic dynamics and fractal geometry. The intended
audience includes undergraduate students of mathematics or other
technical disciplines with a strong background in calculus and some
exposure (or willingness to explore) more advanced topics such as the
basics of real analysis, the complex plane, and linear algebra.

Topics in the text include real iterative dynamics (experimentation,
cobweb plots, bifurcation, and chaos), complex iterative dynamics (Julia
sets, the Mandelbrot set, and the iteration of higher order
polynomials), fractal geometry (self-similarity, iterated function
systems and fractal dimension).

Another important aspect of this text is its emphasis on computation. We
introduce Python code that runs live in the online version to generate
images of many of the sets that we'll meet. Such code is generally quite
simple using basic constructs such as function definition, conditionals,
and iterative loops.

This text was written with [PreTeXt](https://pretextbook.org/) which
makes groovy things like live Python code and nicely formatted online
and print versions easy.

IntroductionIntroductionx:chapter:chapter-intro

One of the central ideas in both chaos theory and fractal geometry is
iteration - i.e., the repitition of a process over and over again. It
might seem a bit odd to base so much of our discussion on a process that
doesn't neccessarily appear to be of fundamental importance to the
unintiated. Thus, in this introduction, we start with a motivation for
iteration - namely, Newton's method for solving equations. From that
natural beginning, we'll meet many of the important ideas that we'll
study further in text.

ExercisesExercisesg:exercises:idp140253883160360

This set of exercises will be mostly experimental. So, fire up your
favorite computational environment. There are lots of potential choices
but this text will generally present examples using Sage.

1x:exercise:exercise-x2-2 Continuing with the example of $f(x)=x^2-2$
explored in , compute ten Newton iterations for several values of $x_0$.
Be sure to choose both positive and negative values and values that are
both large and small in magnitude.

2g:exercise:idp140253883163688 In the previous exercise, what happens
when $x_0=0$? Draw a graph to illustrate the situation.

3g:exercise:idp140253883164648 Let $f$ be a quadractic function that has
two, distinct, real roots but that is otherwise arbitrary. Using a
geometrical understanding of the real Newton's method, show why an
initial seed $x_0$ always leads to a sequence that converges to the
closer of the two roots of $f$.

4g:exercise:idp140253883166680 Let's modify Newton's original example
just a little bit to consider $$f(x) = x^3-2x-2.$$

1.  Compute the corresponding Newton's method iteration function, $N$.

2.  Iterate $N$ from the initial point $x_0 = 0$. What behavior do you
    see?

3.  Iterate $N$ from several initial points $x_0$ close to zero. Now,
    what behavior do you see?

6g:exercise:idp140253883177160 Launch the interactive tool for
generating the basins of attraction of Newton's method for polynomials
here: <https://marksmath.org/visualization/complex_newton/>.

Now, use the tool to generate images for the following polynomials and
answer any additional questions that are asked.

1.  $f(z) = z^4 - 1$

    1.  What are the four roots of the function? Where do they fit into
        the picture?

    2.  Click on the picture. How do you interpret the line that is
        drawn?

2.  $f(z) = (z^2-1)(z-10)$

    1.  What initial step should you take to enter your input?

    2.  What are the roots of the function? How could you account for
        this when generating the picture?

3.  $f(z) = z^3 - 2z - 2$

    1.  You should see some black regions. What's up with that?
