::: {#latex-macros .hidden-content svg="http://www.w3.org/2000/svg" style="display:none"}
\\( \\newcommand{\\lt}{\<} \\newcommand{\\gt}{\>} \\newcommand{\\amp}{&}
\\)
:::

::: {#contents .section .book svg="http://www.w3.org/2000/svg"}
::: {#frontmatter .section .frontmatter}
[Chaos and Fractals]{.title} {#chaos-and-fractals .heading}
----------------------------

::: {.author}
::: {.author-name}
Mark McClure
:::

::: {.author-info}
Department of Mathematics\
University of North Carolina at Asheville\
<mcmcclur@unca.edu>
:::
:::

::: {.date}
August 15, 2021
:::

::: {#preface-1 .section .preface}
### [Preface]{.type} []{.codenumber} [Preface]{.title} {#preface-preface .heading .hide-type}

This is an introductory text on the basics of chaotic dynamics and
fractal geometry. The intended audience includes undergraduate students
of mathematics or other technical disciplines with a strong background
in calculus and some exposure (or willingness to explore) more advanced
topics such as the basics of real analysis, the complex plane, and
linear algebra.

Topics in the text include real iterative dynamics (experimentation,
cobweb plots, bifurcation, and chaos), complex iterative dynamics (Julia
sets, the Mandelbrot set, and the iteration of higher order
polynomials), fractal geometry (self-similarity, iterated function
systems and fractal dimension).

Another important aspect of this text is its emphasis on computation. We
introduce Python code that runs live in the online version to generate
images of many of the sets that we\'ll meet. Such code is generally
quite simple using basic constructs such as function definition,
conditionals, and iterative loops.

This text was written with
[PreTeXt](https://pretextbook.org/){.external} which makes groovy things
like live Python code and nicely formatted online and print versions
easy.
:::
:::

::: {#chapter-intro .section .chapter}
[Chapter]{.type} [1]{.codenumber} [Introduction]{.title} {#chapter-1-introduction .heading}
--------------------------------------------------------

::: {#introduction-1 .section .introduction}
One of the central ideas in both chaos theory and fractal geometry is
iteration - i.e., the repitition of a process over and over again. It
might seem a bit odd to base so much of our discussion on a process that
doesn\'t neccessarily appear to be of fundamental importance to the
unintiated. Thus, in this introduction, we start with a motivation for
iteration - namely, Newton\'s method for solving equations. From that
natural beginning, we\'ll meet many of the important ideas that we\'ll
study further in text.
:::

::: {#section-surprise_in_newton .section .section}
### [Section]{.type} [1.1]{.codenumber} [Surprise in Newton\'s method]{.title} {#section-1.1-surprise-in-newtons-method .heading .hide-type}

::: {#introduction-2 .section .introduction}
Newton\'s method is a technique to estimate roots of a differentiable
function. Invented by Newton in 1669, it remains a stalwart tool in
numerical analysis. When used as intended it\'s remarkably efficient and
stable. After a little experimentation, Newton\'s method yields some
surprises that are very nice illustrations of chaos.
:::

::: {#subsection-newtons_method .section .subsection}
#### [Subsection]{.type} [1.1.1]{.codenumber} [The basics of Newton\'s method]{.title} {#subsection-1.1.1-the-basics-of-newtons-method .heading .hide-type}

Let\'s begin with a look at the example that Newton himself used to
illustrate his method. Let \\(f(x)=x\^3 - 2x - 5\\text{.}\\) The graph
of \\(f\\) shown in [Figure 1.1]{.xref} seems to indicate that \\(f\\)
has a root just to the right of \\(x=2\\text{.}\\)

![[Figure]{.type}[ ]{.space}[1.1[.]{.period}]{.codenumber}[
]{.space}Newton\'s example function for his
method](images/newton_example_function.svg){.contained}

Newton figured that, if the root of \\(f\\) is a little bigger than
\\(2\\text{,}\\) then he could write it as \\(2+\\Delta x\\text{.}\\) He
then plugged this into \\(f\\) to get

::: {.displaymath}
\\begin{align\*} f(2+\\Delta x) &= (2+\\Delta x)\^3 - 2(2+\\Delta x) -
5\\\\ &= 8 + 3\\times2\^2\\Delta x + 3\\times2\\Delta x\^2 + \\Delta
x\^3 -4-2\\Delta x - 5\\\\ &= -1 +10\\Delta x + 6\\Delta x\^2 + \\Delta
x\^3\\\\ &\\approx -1+10\\Delta x. \\end{align\*}
:::

In that last step, since \\(\\Delta x\\) is small, he figures that
higher powers of \\(\\Delta x\\) are negligibly small. Thus, he figures
that \\(-1+10\\Delta x \\approx 0\\) so that \\(\\Delta x \\approx
1/10\\text{.}\\)

The point is that, if \\(2\\) is a good guess at a root of
\\(f\\text{,}\\) then \\(2+1/10 = 2.1\\) should be an even better guess.
A glance at the graph seems to verify this. Of course, we could then
repeat the process using \\(2.1\\) as the initial guess. We should get
an *even better* estimate. The process can be repeated as many times as
desired. This is the basis of *iteration*.
:::

::: {#subsection-real_newton .section .subsection}
#### [Subsection]{.type} [1.1.2]{.codenumber} [Newton\'s method in the real domain]{.title} {#subsection-1.1.2-newtons-method-in-the-real-domain .heading .hide-type}

::: {#introduction-3 .section .introduction}
Let\'s take a more general look at Newton\'s method. The problem is to
estimate a root of a real, differentiable function \\(f\\text{,}\\) i.e.
a value of \\(x\\) such that \\(f(x)=0\\text{.}\\) Suppose also that we
have an initial guess \\(x_0\\) for the actual value of the root, which
we denote \\(r\\text{.}\\) Often, the value of \\(x_0\\) will be based
on a graph. Since \\(f\\) is differentiable, we can estimate \\(r\\)
with the root of the tangent line approximation to \\(f\\) at
\\(x_0\\text{;}\\) let\'s call this point \\(x_1\\text{.}\\) When
\\(x_0\\) is close to \\(r\\text{,}\\) we often find that \\(x_1\\) is
even closer. This process is illustrated in [Figure 1.2]{.xref} where it
indeed appears that \\(x_1\\) is much closer to \\(r\\) than
\\(x_0\\text{.}\\)

![[Figure]{.type}[ ]{.space}[1.2[.]{.period}]{.codenumber}[ ]{.space}One
step in Newton\'s method](images/newton_step.svg){.contained}

We now find a formula for \\(x_1\\) in terms of the given information.
Recall that \\(x_1\\) is the root of the tangent line approximation to
\\(f\\) at \\(x_0\\text{;}\\) let\'s call this tangent line
approximation \\(\\ell\\text{.}\\) Thus,

::: {.displaymath}
\\begin{equation\*} \\ell(x) = f(x_0) + f\'(x_0)(x-x_0)
\\end{equation\*}
:::

and \\(\\ell(x_1)=0\\text{.}\\) Thus, we must simply solve

::: {.displaymath}
\\begin{equation\*} f(x_0) + f\'(x_0)(x-x_0) = 0 \\end{equation\*}
:::

for \\(x\\) to get \\(x_1 = x_0-f(x_0)/f\'(x_0)\\text{.}\\)

Now, of course, \\(x_1\\) is again a point that is close
\\(r\\text{.}\\) Thus, we can repeat the process with \\(x_1\\) as the
guess. The new, better estimate will then be

::: {.displaymath}
\\begin{equation\*} x_2 = x_1 - \\frac{f(x_1)}{f\'(x_1)}.
\\end{equation\*}
:::

The process can then repeat. Thus, we can define a sequence \\((x_n)\\)
*recursively* by

::: {.displaymath}
\\begin{equation\*} x\_{n+1} = x_n - \\frac{f(x_n)}{f\'(x_n)}.
\\end{equation\*}
:::

This process is called *iteration* and the sequence it generates often
converges to the root \\(r\\text{.}\\)
:::

::: {#subsubsection-1 .section .subsubsection}
##### [Subsubsection]{.type} []{.codenumber} [Examples]{.title} {#subsubsection-examples .heading .hide-type}

::: {#introduction-4 .section .introduction}
We now present several examples to illustrate the variety of things that
can happen when we apply Newton\'s method. Throughout, we have a
function \\(f\\) and we defined the corresponding Newton\'s method
iteration function

::: {.displaymath}
\\begin{equation\*} N(x) = x - \\frac{f(x)}{f\'(x)}. \\end{equation\*}
:::

We then iterate the function \\(N\\) from some starting point or,
perhaps, from several starting points.
:::

###### [Example]{.type}[ ]{.space}[1.3]{.codenumber}[.]{.period} {#example-1.3. .heading}

We start with \\(f(x)=x\^2-2\\text{.}\\) Of course, \\(f\\) has two
roots, namely \\(\\pm\\sqrt{2}\\text{.}\\) Thus, we might think, of the
application of Newton\'s method to \\(f\\) as a tool to find good
approximations to \\(\\sqrt{2}\\text{.}\\)

First, we compute \\(N\\text{:}\\)

::: {.displaymath}
\\begin{align\*} N(x) &= x-f(x)/f\'(x) = x-\\frac{x\^2-2}{2x} \\\\ &=
x-\\left(\\frac{x\^2}{2x}-\\frac{2}{2x}\\right) =
x-\\left(\\frac{x}{2}-\\frac{1}{x}\\right) = \\frac{x}{2}+\\frac{1}{x}.
\\end{align\*}
:::

Now, suppose that \\(x_0=1\\text{.}\\) Then,

::: {.displaymath}
\\begin{align\*} x_1 &= N(1) = \\frac{1}{2}+\\frac{1}{1} =
\\frac{3}{2}\\\\ x_2 &= N(3/2) = \\frac{3/2}{2}+\\frac{1}{3/2} =
\\frac{17}{12}\\\\ x_3 &= N(17/12) = \\frac{17/12}{2}+\\frac{1}{17/12} =
\\frac{577}{408} \\end{align\*}
:::

Note that

::: {.displaymath}
\\begin{equation\*} (577/408)\^2 = 332929/166464 = 2+1/166464
\\end{equation\*}
:::

so that third iterate is quite close to \\(\\sqrt{2}\\text{.}\\)

Note that we\'ve obtained a *rational* approximation to
\\(\\sqrt{2}\\text{.}\\) At the same time, it\'s clear that it would be
nice to perform these computations on a computer. In that context, we
might generate a *decimal* approximation to \\(\\sqrt{2}\\text{.}\\)
Here\'s how this process might go in Sage:

::: {#sage-1 .sagecell-sage}
:::

Note how quickly the process has converged to 12 digits of precision.

Of course, \\(f\\) has two roots. How can we choose \\(x_0\\) so that
the process converges to \\(-\\sqrt{2}\\text{?}\\) You\'ll explore this
question computationally in [Exercise 1.3.1]{.xref}. It\'s worth noting,
though, that a little geometric understanding can go a long way.
[Figure 1.4]{.xref}, for example, shows us that if we start with a
number \\(x_0\\) between zero and \\(\\sqrt{2}\\text{,}\\) then
\\(x_1\\) will be larger than \\(\\sqrt{2}\\text{.}\\) The same picture
shows us that any number larger than \\(\\sqrt{2}\\) leads to a sequence
that converges to \\(\\sqrt{2}\\text{.}\\)

![[Figure]{.type}[ ]{.space}[1.4[.]{.period}]{.codenumber}[
]{.space}Three steps in Newton\'s method for
\\(f(x)=x\^2-2\\)](images/newton_steps.svg){.contained}

###### [Example]{.type}[ ]{.space}[1.5]{.codenumber}[.]{.period} {#example-1.5. .heading}

We now take a look at \\(f(x)=x\^2+3\\text{.}\\) A simple look at the
graph of \\(f\\) shows that it doesn\'t even hit the \\(x\\)-axis; thus,
\\(f\\) has no roots. It\'s not at all clear what to expect from
Newton\'s method.

A simple computation shows that the Newton\'s method iteration function
is

::: {.displaymath}
\\begin{equation\*} N(x) = \\frac{x}{2} - \\frac{3}{2x}.
\\end{equation\*}
:::

Note that \\(N(1)=-1\\) and \\(N(-1)=1\\text{.}\\) In the general
context of iteration that we\'ll consider later, we\'ll say that the
points \\(1\\) and \\(-1\\) lie on an orbit of period 2 under iteration
of the function \\(N\\text{.}\\)

Sequences of other points seem more complicated so we turn to the
computer. Suppose that we change the initial seed \\(x_0=1\\) just a
little tiny bit and iterate with Sage.

::: {#sage-2 .sagecell-sage}
:::

Well, there appears to be no particular pattern in the numbers. In fact,
if we generate 1000 iterates an plot those that lie within 10 units of
the origin on a number line, we get [Figure 1.6]{.xref}. This is our
first illustration of chaotic behavior. Not just because we see points
spread all throughout the interval but also because we appeared to have
a stable orbit when \\(x_0=1\\text{.}\\) Why should the behavior be so
different when we change that initial seed to \\(x_0=0.99\\text{?}\\)

![[Figure]{.type}[ ]{.space}[1.6[.]{.period}]{.codenumber}[
]{.space}Chaotic behavior from Newton\'s
method](images/newton_chaos.svg){.contained}

###### [Example]{.type}[ ]{.space}[1.7]{.codenumber}[.]{.period} {#example-1.7. .heading}

Newton\'s original example had one real root, [Example 1.3]{.xref} had
two real roots and [Example 1.5]{.xref} had no real roots. Let\'s take a
look at an example with *lots* real roots, namely
\\(f(x)=\\cos(x)\\text{.}\\)

Generally, the closer your initial seed is to a root, the more likely
the sequence starting from that seed is to converge to that root. What
happens, though, if we start some place that\'s not so close to a root?
What if we start close to the maximum - near zero? Let\'s investigate in
code.

::: {#sage-3 .sagecell-sage}
:::

OK, let\'s pick this code apart. The inner for loop looks like so:

``` {.code-block .tex2jax_ignore}
xi = random()/10
for i in range(8):
    xi = N(xi)
```

Thus, xi is set to be a random number between \\(0\\) and
\\(0.1\\text{;}\\) the for loop then iterates the Newton\'s method
function in for the cosine from that initial seed 8 times. The outer for
loop simply performs this experiment 10 times. After each run of the
experiment, we print the resulting \\(xi\\) - along with the value of
the cosine at that point, to check that we\'re indeed close to a root of
the cosine. It\'s striking that we get 9 different results over 10 runs
even though the starting points are so close to one another.

[Figure 1.8]{.xref} gives some clue as to what\'s going on. Recall that
we can envision a Newton step for a function \\(f\\) from a point
\\(x_i\\) by drawing the line that is tangent to the graph of \\(f\\) at
the point \\((x_i,f(x_i))\\text{.}\\) The value of \\(x_i\\) is then the
point of intersection of this line with the \\(x\\)-axis. Because the
slope at the maximum is zero, the value of this point of intersection is
very sensitive to small changes. In fact, there are infinitely many
roots of the cosine any one of which could be hit by some initial seed
in this tiny interval.

![[Figure]{.type}[ ]{.space}[1.8[.]{.period}]{.codenumber}[
]{.space}Initial Newton steps for the
cosine](images/real_newton_cosine.svg){.contained}
:::
:::

::: {#subsection-complex_newton .section .subsection}
#### [Subsection]{.type} [1.1.3]{.codenumber} [Newton\'s method in the complex domain]{.title} {#subsection-1.1.3-newtons-method-in-the-complex-domain .heading .hide-type}

::: {#introduction-5 .section .introduction}
Let\'s move now to the complex domain, where even crazier things can
happen. To understand this stuff, of course, you\'ll need a basic
understanding of complex numbers but it\'s really not a daunting amount
of information. You\'ll need to know that a complex number \\(z\\) has
the form

::: {.displaymath}
\\begin{equation\*} z = x+iy, \\end{equation\*}
:::

where \\(x\\) and \\(y\\) are real numbers (the real and imaginary parts
of \\(z\\)) and \\(i\\) is the imaginary unit (thus \\(i\^2=-1\\)).
You\'ll also need to know (or accept) that you can do arithmetic with
complex numbers and plot them in a plane, called the complex plane.
We\'ll discuss complex variables in a more detail when we jump into
complex dynamics more completely.
:::

::: {#subsubsection-2 .section .subsubsection}
##### [Subsubsection]{.type} []{.codenumber} [Cayley\'s question]{.title} {#subsubsection-cayleys-question .heading .hide-type}

In the 1870s, the prolific British mathematician Arthur Cayley (whose
name is all over abstract algebra) posed the following interesting
question: Given a Suppose that \\(p\\) is a complex polynomial and
\\(z_0\\) is an initial seed that we might use for Newton\'s method.
Generally, \\(p\\) will have several roots scattered throughout the
complex plane. Is it possible to tell to which of those roots (if any)
Newton\'s method will converge to when we start at \\(z_0\\text{?}\\)

Generally, the closer an initial seed is to a root, the more likely that
seed will lead to a sequence that converges to the root. It might be
reasonable to guess that the process always converges to the root that
is closest to the initial seed. Cayley proved that this is true for
quadratic functions but was commented that the general question is much
more difficult for cubics. With the power of the computer, there is a
very colorful way to explore the question

###### [Algorithm]{.type}[ ]{.space}[1.9]{.codenumber}[.]{.period}[ ]{.space}[Coloring basins of attraction for Newton\'s method.]{.title} {#algorithm-1.9.-coloring-basins-of-attraction-for-newtons-method. .heading}

1.  ::: {#li-1}
    Given: A function \\(f:\\mathbb C \\to \\mathbb C\\text{.}\\)
    :::

2.  ::: {#li-2}
    Choose a rectangle \\(R\\) in the complex plane with sides parallel
    to the real and imaginary axes.

    -   ::: {#li-3}
        The points in \\(R\\) represent potential initial seeds when
        applying Newton\'s method to \\(f\\text{.}\\)
        :::
    :::

3.  ::: {#li-4}
    Discretize the rectangle into points of the form

    ::: {.displaymath}
    \\begin{equation\*} z\_{0,jk} = (a+j\\Delta x) + (b + k\\Delta y)k.
    \\end{equation\*}
    :::
    :::

4.  ::: {#li-5}
    For each point \\(z\_{0,jk}\\) perform Newton\'s iteration to
    generate a sequence \\((z\_{n,jk})\_n\\) until one of two things
    happen:

    -   ::: {#li-6}
        \\(\|f(z\_{n,jk})\| \< \\varepsilon\\text{,}\\) where
        \\(\\varepsilon\\) is some pre-specified small number. We assume
        that the process has converged to a root; color the initial seed
        \\(z\_{0,jk}\\) according to which root the process converged to
        and shade the initial seed according to how many iterates this
        process took.
        :::

    -   ::: {#li-7}
        The iteration count exceeds some pre-specified bailout; we color
        the initial seed \\(z\_{0,jk}\\) black.
        :::
    :::

Let\'s take a look at a simple, quadratic example.

###### [Example]{.type}[ ]{.space}[1.10]{.codenumber}[.]{.period} {#example-1.10. .heading}

Let \\(p(z)=z\^2+3\\text{.}\\) We already played with this function in
the real case back in [Example 1.5]{.xref} and the computer indicated
that there might be chaos on the real line. When we allow complex
inputs, though, there are two roots - one at \\(\\sqrt{3}i\\) (above the
real axis) and one at \\(-\\sqrt{3}i\\) (below the real axis). If the
process always converges to the root that is closest to the initial
seed, then seeds in the upper half plane should converge to
\\(\\sqrt{3}i\\) while seeds in the lower half plane should converge to
\\(-\\sqrt{3}i\\text{.}\\) We don\'t have the tools to prove this yet,
but we can investigate with [Algorithm 1.9]{.xref}. The result is shown
in [Figure 1.11]{.xref}.

![[Figure]{.type}[ ]{.space}[1.11[.]{.period}]{.codenumber}[
]{.space}Attractive basins for
\\(f(z)=z\^2+3\\)](images/quadratic_newton_coloring.png){.contained}

Now, let\'s take a look at a classic, cubic example.

###### [Example]{.type}[ ]{.space}[1.12]{.codenumber}[.]{.period} {#example-1.12. .heading}

Let \\(p(z)=z\^3 - 1\\text{.}\\) As a complex, cubic polynomial, we
expect \\(p\\) to have three roots. It\'s easy to see that \\(z=1\\) is
a root. This means that \\(z-1\\) is a factor, which makes it easier to
find that

::: {.displaymath}
\\begin{equation\*} p(z) = (z-1)(z\^2+z+1). \\end{equation\*}
:::

We can then apply the quadratic formula to find that the other two roots
are

::: {.displaymath}
\\begin{equation\*} \\frac{-1\\pm\\sqrt{-3}}{2} =
-\\frac{1}{2}\\pm\\frac{\\sqrt{3}}{2}i. \\end{equation\*}
:::

Note that all three roots can be clearly seen in [Figure 1.13]{.xref},
which shows the result of [Algorithm 1.9]{.xref}.

![[Figure]{.type}[ ]{.space}[1.13[.]{.period}]{.codenumber}[
]{.space}Attractive basins for
\\(f(z)=z\^2+3\\)](images/x3m1_coloring.png){.contained}

[Figure 1.13]{.xref} is just an incredible picture. We can clearly see
the three roots of \\(p\\) and, indeed, if we start close enough to a
root we do converge to that root. The boundary between the basins seems
to be incredibly complicated, though.

As a final example, let\'s take a look at the complex cosine.

###### [Example]{.type}[ ]{.space}[1.14]{.codenumber}[.]{.period} {#example-1.14. .heading}

Let \\(f(z)=\\cos(z)\\text{.}\\) Of course, we played with the real
cosine back in [Example 1.7]{.xref}. There, we saw that in any tiny
interval containing zero, an initial seed might converge to any of
infinitely many roots. In the complex case, the basins of attraction are
shown in [Figure 1.15]{.xref}, and a zoom is shown in
[Figure 1.16]{.xref}.

![[Figure]{.type}[ ]{.space}[1.15[.]{.period}]{.codenumber}[
]{.space}Attractive basins for the
cosine](images/complex_cosine.png){.contained}

![[Figure]{.type}[ ]{.space}[1.16[.]{.period}]{.codenumber}[ ]{.space}A
zoom into the basins of the
cosine](images/complex_cosine_zoom.png){.contained}

Two more incredible pictures! Note the periodicity in
[Figure 1.15]{.xref}. Each root seems to have its own column of
attraction. The boundaries between the basins are again very
complicated. In the zoom of [Figure 1.16]{.xref}, t looks like there\'s
an infinite sequence of circles collapsing on either side of the origin.
This agrees with our observations in the real case of
[Example 1.7]{.xref}.

Generating pictures for the Newton\'s method is great fun. There is an
online tool that allows you to generate the basins of attraction for an
(almost) arbitrary polynomial here:

[`https://marksmath.org/visualization/complex_newton/`{.code-inline
.tex2jax_ignore}](https://marksmath.org/visualization/complex_newton/){.external}.
:::
:::
:::

::: {#section-scope_of_chaos .section .section}
### [Section]{.type} [1.2]{.codenumber} [The scope of chaos]{.title} {#section-1.2-the-scope-of-chaos .heading .hide-type}

::: {#introduction-6 .section .introduction}
The previous section introduced you a few fascinating ideas and images
(functional iteration in real and complex variables and infinitely
convoluted shapes that have become knows as fractal) - all in the
context of Newton\'s method. The purpose of this short section is to
indicate and illustrate a few other areas in which chaos and fractals
occur.
:::

::: {#subsection-real_iteration .section .subsection}
#### [Subsection]{.type} [1.2.1]{.codenumber} [The iteration of real functions]{.title} {#subsection-1.2.1-the-iteration-of-real-functions .heading .hide-type}

We were introduced to the idea of real iteration back in
[Subsection 1.1.2](contents.html#subsection-real_newton "Subsection 1.1.2: Newton's method in the real domain"){.internal}
but there\'s no reason the function we iterate needs to come from
Newton\'s method. [Figure 1.17]{.xref} illustrates iteration using a
geometric cool called a *cobweb plot*. In part (a) we see the iteration
of \\(N(x)=x/2+1/x\\text{,}\\) that arises in Newton\'s method. In part
(b) we the iteration of \\(f(x)=3.1x(1-x)\\text{.}\\) This is an example
of a *logistic* function and really has nothing directly to do with
Newton\'s method.

![[Figure]{.type}[ ]{.space}[1.17[.]{.period}]{.codenumber}[
]{.space}Two cobwebs that arises in real
iteration](images/intro_cobwebs.svg){.contained}

The logistic function above is a member of a *family* of functions - the
logistic family. These functions have the form \\(f_r(x) =
rx(1-x)\\text{.}\\) When studying a family of functions like this we are
often interested in the various types of behavior that might arise. We
can explore these possibilites with a tool called a *bifurcation
diagram*. The bifurcation diagram for the logistic family is shown in
[Figure 1.18]{.xref}.

![[Figure]{.type}[ ]{.space}[1.18[.]{.period}]{.codenumber}[
]{.space}The bifurcation diagram for the logistic
family](images/logistic_bifurcation.png){.contained}
:::

::: {#subsection-complex_iteration .section .subsection}
#### [Subsection]{.type} [1.2.2]{.codenumber} [The iteration of complex functions]{.title} {#subsection-1.2.2-the-iteration-of-complex-functions .heading .hide-type}

We were introduced to the idea of complex iteration back in
[Subsection 1.1.3](contents.html#subsection-complex_newton "Subsection 1.1.3: Newton's method in the complex domain"){.internal}
and, again, there\'s no reason the function we iterate needs to come
from Newton\'s method. In the context of complex iteration we\'ll meet
Julia sets, a few of which are shown in [Figure 1.19]{.xref}

![[Figure]{.type}[ ]{.space}[1.19[.]{.period}]{.codenumber}[
]{.space}Some Julia sets](images/intro_julia_sets.png){.contained}

The Julia sets shown in [Figure 1.19]{.xref} all arise from the
iteration of functions in the quadratic family - i.e. from the iteration
of functions of the form \\(f(z)=z\^2+c\\text{.}\\) It is in this
context that the famous Mandelbrot set shown in [Figure 1.20]{.xref}
arises.

![[Figure]{.type}[ ]{.space}[1.20[.]{.period}]{.codenumber}[
]{.space}The Mandelbrot
set](images/intro_mandelbrot_set.png){.contained}
:::

::: {#subsection-geometric_iteration .section .subsection}
#### [Subsection]{.type} [1.2.3]{.codenumber} [Geometric iteration and fractal geometry]{.title} {#subsection-1.2.3-geometric-iteration-and-fractal-geometry .heading .hide-type}

When studying fractal geometry, we might iterate a function that maps
sets to other sets. Such an example is shown in [Figure 1.21]{.xref}.
The limiting figure, called the Sierpinski triangle is shown in
[Figure 1.22]{.xref}.

![[Figure]{.type}[ ]{.space}[1.21[.]{.period}]{.codenumber}[
]{.space}Geometric
iteration](images/geometric_iteration.svg){.contained}

![[Figure]{.type}[ ]{.space}[1.22[.]{.period}]{.codenumber}[
]{.space}The Sierpinski
triangle](images/intro_sierpinski_triangle.png){.contained}

The specific type of function that we iterate in this context is called
an *iterated function system* Some amazingly intricate images can be
constructed using an iterated function system. [Figure 1.23]{.xref}
shows the Barnsely fern, which is described by a list of just four
functions.

![[Figure]{.type}[ ]{.space}[1.23[.]{.period}]{.codenumber}[
]{.space}The Barnsley fern](images/intro_barnsley_fern.png){.contained}
:::
:::

::: {#exercises-1 .section .exercises}
### [Exercises]{.type} [1.3]{.codenumber} [Exercises]{.title} {#exercises-1.3-exercises .heading .hide-type}

::: {#introduction-7 .section .introduction}
This set of exercises will be mostly experimental. So, fire up your
favorite computational environment. There are lots of potential choices
but this text will generally present examples using Sage.
:::

###### [1[.]{.period}]{.codenumber} {#section .heading}

Continuing with the example of \\(f(x)=x\^2-2\\) explored in
[Example 1.3]{.xref}, compute ten Newton iterations for several values
of \\(x_0\\text{.}\\) Be sure to choose both positive and negative
values and values that are both large and small in magnitude.

###### [2[.]{.period}]{.codenumber} {#section-1 .heading}

In the previous exercise, what happens when \\(x_0=0\\text{?}\\) Draw a
graph to illustrate the situation.

###### [3[.]{.period}]{.codenumber} {#section-2 .heading}

Let \\(f\\) be a quadractic function that has two, distinct, real roots
but that is otherwise arbitrary. Using a geometrical understanding of
the real Newton\'s method, show why an initial seed \\(x_0\\) always
leads to a sequence that converges to the closer of the two roots of
\\(f\\text{.}\\)

###### [4[.]{.period}]{.codenumber} {#section-3 .heading}

Let\'s modify Newton\'s original example just a little bit to consider

::: {.displaymath}
\\begin{equation\*} f(x) = x\^3-2x-2. \\end{equation\*}
:::

a.  ::: {#li-8}
    Compute the corresponding Newton\'s method iteration function,
    \\(N\\text{.}\\)
    :::

b.  ::: {#li-9}
    Iterate \\(N\\) from the initial point \\(x_0 = 0\\text{.}\\) What
    behavior do you see?
    :::

c.  ::: {#li-10}
    Iterate \\(N\\) from several initial points \\(x_0\\) close to zero.
    Now, what behavior do you see?
    :::

###### [5[.]{.period}]{.codenumber} {#section-4 .heading}

[Figure 1.24]{.xref} shows the graph of the function

::: {.displaymath}
\\begin{equation\*} f(x) = \\frac{1}{3} x (x + 1) (x - 3) (x\^2 - 2).
\\end{equation\*}
:::

The green dots represent points on the graph with \\(x\\)-coordinates
that we might consider as initial seeds for Newton\'s method.

a.  ::: {#li-11}
    Suppose we start at the green dot whose \\(x\\) coordinate is just
    slightly larger than 1. To which root do you think the process will
    converge?
    :::

b.  ::: {#li-12}
    Suppose we start at the green dot whose \\(x\\) coordinate is
    between 2 and 3. To which root do you think the process will
    converge?
    :::

c.  ::: {#li-13}
    Find a specific value of the initial seed \\(x_0\\) between 2 and 3
    with the property that the process converges to the smallest root of
    the function.
    :::

d.  ::: {#li-14}
    Find a specific value of the initial seed \\(x_0\\) between 2 and 3
    with the property that the process converges to the value 1.
    :::

###### [6[.]{.period}]{.codenumber} {#section-5 .heading}

Launch the interactive tool for generating the basins of attraction of
Newton\'s method for polynomials here:
[`https://marksmath.org/visualization/complex_newton/`{.code-inline
.tex2jax_ignore}](https://marksmath.org/visualization/complex_newton/){.external}.

Now, use the tool to generate images for the following polynomials and
answer any additional questions that are asked.

a.  ::: {#li-15}
    \\(f(z) = z\^4 - 1\\)

    i.  ::: {#li-16}
        What are the four roots of the function? Where do they fit into
        the picture?
        :::

    ii. ::: {#li-17}
        Click on the picture. How do you interpret the line that is
        drawn?
        :::
    :::

b.  ::: {#li-18}
    \\(f(z) = (z\^2-1)(z-10)\\)

    i.  ::: {#li-19}
        What initial step should you take to enter your input?
        :::

    ii. ::: {#li-20}
        What are the roots of the function? How could you account for
        this when generating the picture?
        :::
    :::

c.  ::: {#li-21}
    \\(f(z) = z\^3 - 2z - 2\\)

    i.  ::: {#li-22}
        You should see some black regions. What\'s up with that?
        :::
    :::

![[Figure]{.type}[ ]{.space}[1.24[.]{.period}]{.codenumber}[
]{.space}The graph of the function for problem
5](images/real_newton_guess_hw.svg){.contained}
:::
:::

::: {#real_iteration .section .chapter}
[Chapter]{.type} [2]{.codenumber} [The iteration of real functions]{.title} {#chapter-2-the-iteration-of-real-functions .heading}
---------------------------------------------------------------------------

::: {#introduction-8 .section .introduction}
###### Introduction. {#introduction. .heading}

In this chapter, we take a close look at discrete, real dynamics. That
is, we study the iteration of functions \\(f:\\mathbb R \\to \\mathbb
R\\text{.}\\) This concept was introduced intuitively in
[Subsection 1.1.2](contents.html#subsection-real_newton "Subsection 1.1.2: Newton's method in the real domain"){.internal}.
:::

::: {#section-basic_notions .section .section}
### [Section]{.type} [2.1]{.codenumber} [Basic notions]{.title} {#section-2.1-basic-notions .heading .hide-type}

We begin with some of the most fundamental definitions and examples.
While these definitions are stated for real functions, many of them
extend quite easily to other contexts.

###### [Definition]{.type}[ ]{.space}[2.1]{.codenumber}[.]{.period} {#definition-2.1. .heading}

Let \\(x_0\\in\\mathbb R\\) be an initial point and define a sequence
\\((x_n)\\) recursively by \\(x\_{n+1} = f(x_n)\\text{.}\\) This
sequence is called *the orbit* of \\(x_0\\) under iteration of
\\(f\\text{.}\\)

Some orbits don\'t move; they are fixed.

###### [Definition]{.type}[ ]{.space}[2.2]{.codenumber}[.]{.period} {#definition-2.2. .heading}

A point \\(x_0 \\in \\mathbb R\\) is a *fixed point* of \\(f\\) if
\\(f(x_0)=x_0\\text{.}\\)

Sometimes an orbit might return to the original starting point.

###### [Definition]{.type}[ ]{.space}[2.3]{.codenumber}[.]{.period} {#definition-2.3. .heading}

Suppose that the orbit \\((x_n)\\) satisfies

::: {.displaymath}
\\begin{equation\*} x_0 \\to x_1 \\to x_2 \\cdots \\to x\_{n-1} \\to x_0
\\end{equation\*}
:::

and \\(x_n=x_0\\text{.}\\) Such an orbit is called a *periodic orbit*
and the points themselves are called *periodic points*. If \\(x_k \\neq
x_0\\) for \\(k=1,2,\\ldots,n-1\\text{,}\\) then \\(n\\) is called the
*period* of the orbit.

Note that a fixed point is a periodic point with period one.

Sometimes, the orbit of a non-periodic point might land on a periodic
orbit.

###### [Definition]{.type}[ ]{.space}[2.4]{.codenumber}[.]{.period} {#definition-2.4. .heading}

If the zeroth term \\(x_0\\) of an orbit \\((x_n)\\) is not periodic but
\\(x_n\\) is periodic for some \\(n\\text{,}\\) then \\(x_0\\) and its
orbit are called *pre-periodic*.

###### [Example]{.type}[ ]{.space}[2.5]{.codenumber}[.]{.period} {#example-2.5. .heading}

Let \\(f(x) = 2x+1\\text{.}\\) We could compute a few terms of the orbit
of \\(x_0=1\\) by direct comutation:

::: {.displaymath}
\\begin{equation\*} 1\\to3\\to7\\to14\\to31\\to\\cdots \\end{equation\*}
:::

It\'s not too hard to guess that a general formula for
\\(n\^{\\text{th}}\\) term might be \\(x_n = 2\^{n+1}-1\\text{.}\\) You
should check this for the first few values of \\(n\\text{.}\\)

It\'s easy to check that \\(x_0=-1\\) is a fixed point. It seems
unlikely that there are other fixed points or periodic orbits of any
period.

###### [Example]{.type}[ ]{.space}[2.6]{.codenumber}[.]{.period} {#example-2.6. .heading}

Let \\(f(x) = x\^2-1\\text{.}\\) Then zero is a periodic point and one
is a pre-periodic point, as the reader may easily verify.

To find a fixed point, we can simply set \\(f(x)=x\\) and solve the
resulting equation. In this case, we get

::: {.displaymath}
\\begin{equation\*} x\^2-1=x \\: \\text{ or } \\: x\^2-x-1 = 0.
\\end{equation\*}
:::

We can then apply the quadratic formula to find that

::: {.displaymath}
\\begin{equation\*} x=\\frac{1\\pm\\sqrt{5}}{2} \\end{equation\*}
:::

are both fixed.

Often, it helps to express these ideas in terms of composition of
functions. We denote the \\(n\\) fold composition of a function with
itself by \\(f\^n\\text{.}\\) That is, \\(f\^2 = f\\circ f\\) and
\\(f\^n = f\\circ f\^{n-1}\\text{.}\\) (Be careful note to confuse this
with raising a function to a power.) A more complete understanding of
periodicity arises from the study of the functions \\(f\^n\\text{.}\\)
For example, a point \\(x_0\\) has period \\(n\\) iff
\\(f\^n(x_0)=x_0\\) but \\(f\^k(x_0)\\neq x_0\\) for
\\(k=1,2,\\ldots,n-1\\text{.}\\)

###### [Checkpoint]{.type}[ ]{.space}[2.7]{.codenumber}[.]{.period} {#checkpoint-2.7. .heading}

Let \\(f(x) = 2 x\^2-3 x-6\\text{.}\\)

1.  ::: {#li-23}
    Find the first three terms of the orbit of \\(x_0=1\\text{.}\\)
    :::

2.  ::: {#li-24}
    Find all fixed points of \\(f.\\)
    :::

3.  ::: {#li-25}
    Write down an equation that any point of period 2 should satisfy.
    :::
:::

::: {#section-computer_experimentation .section .section}
### [Section]{.type} [2.2]{.codenumber} [Computer experimentation]{.title} {#section-2.2-computer-experimentation .heading .hide-type}

::: {#introduction-9 .section .introduction}
It doesn\'t take long to realize that a little computer power will help
develop intution much better than, say, doing a lot of arithmetic by
hand. We\'ll often use [Sage](https://sagemath.org){.external} for basic
exploration of iterative dynamics. Here are a few examples.
:::

::: {#subsection-computing_orbits .section .subsection}
#### [Subsection]{.type} [2.2.1]{.codenumber} [Computing orbits]{.title} {#subsection-2.2.1-computing-orbits .heading .hide-type}

Suppose \\(f(x) = \\frac{1}{5}x\^2 - 2x + 6\\text{.}\\) Here\'s how to
compute the first five iterates of \\(x_0=1\\) under \\(f\\) using Sage:

::: {#sage-4 .sagecell-sage}
:::

Note that the computation is exact. That is, we get rational numbers
like \\(21/5\\text{,}\\) rather than decimal approximations like
\\(4.2\\text{.}\\) Often we would prefer decimal approximations. Let\'s
set xi = 1.0 in the code block above and compute 100 iterates.

::: {#sage-5 .sagecell-sage}
:::

Sure looks like we\'ve found a pattern! Perhaps, it\'s an orbit of
period 2?
:::

::: {#subsection-finding_periodic_orbits .section .subsection}
#### [Subsection]{.type} [2.2.2]{.codenumber} [Finding periodic orbits]{.title} {#subsection-2.2.2-finding-periodic-orbits .heading .hide-type}

Continuing with the example of the last sub-section, suppose we\'d like
to find all orbits of period 2 for \\(f(x) = \\frac{1}{5}x\^2 - 2x +
6\\text{.}\\) I guess we should let \\(F(x)=f\^2(x)\\) and then find all
fixed points of \\(F\\) or, equivalently, find all roots
\\(F(x)-x\\text{.}\\) We can automate this procedure like so:

::: {#sage-6 .sagecell-sage}
:::

Each root is returned as a (value,multiplicity) pair. Note that the 1.38
and 3.618 agree with our prior computation; those form the orbit of
period 2. The other points are fixed points. Of course, those should be
the points of intersection with the line \\(y=x\\text{.}\\) We can
illustrate that with Sage too:

::: {#sage-7 .sagecell-sage}
:::
:::

###### [Checkpoint]{.type}[ ]{.space}[2.8]{.codenumber}[.]{.period}[ ]{.space}[Find an orbit of period three.]{.title} {#checkpoint-2.8.-find-an-orbit-of-period-three. .heading}

Given the function \\(f(x) = 7 x\^2+14 x+\\frac{23}{4}\\text{,}\\)

1.  ::: {#li-26}
    Iterate \\(f\\) from the starting point \\(x_0=1.0\\) twenty times.
    What does the long term behavior appear to be?
    :::

2.  ::: {#li-27}
    Iterate \\(f\\) from the starting point \\(x_0=-1.0\\) two hundred
    times. What does the long term behavior appear to be?
    :::

3.  ::: {#li-28}
    Write down an equation that an orbit of period 3 should satisfy and
    solve that equation using Sage.
    :::
:::

::: {#section-graphical_analysis .section .section}
### [Section]{.type} [2.3]{.codenumber} [Graphical analysis]{.title} {#section-2.3-graphical-analysis .heading .hide-type}

There is an efficient geometric tool to visualize functional iteration.
The basic idea is simple: Suppose we graph the function \\(f\\) together
with the line \\(y=x\\text{.}\\) If those two graphs intersect; that
point of intersection is a fixed point. Now, suppose we\'re on the line
at the point \\((x_i,x_i)\\text{.}\\) If we move vertically to the graph
of the function, we preserve the \\(x\\) coordinate but change the
\\(y\\) coordinate to \\(f(x_i)\\text{.}\\) Thus, we arrive at the point
\\((x_i,f(x_i)) = (x_i,x\_{i+1})\\text{.}\\) If we then move
horizontally back to the line \\(y=x\\) we now preserve the \\(y\\)
coordinate but change the \\(x\\) coordinate so that the \\(x\\) and
\\(y\\) coordinates are the same. Thus, we arrive at the point
\\((x\_{i+1},x\_{i+1})\\text{.}\\)

In summary: The process of moving vertically from a point on the line
\\(y=x\\) to the graph of \\(f\\) and back to the line horizontally is a
geometric representation of one application of the function
\\(f\\text{.}\\) This step is illustrated in [Figure 2.9]{.xref}(a).
Repeated application of this process represents repeated application of
\\(f\\text{,}\\) i.e. iteration. This is illustrated in
[Figure 2.9]{.xref}(b). Note that the orbit appears to be attractive.

![[Figure]{.type}[ ]{.space}[2.9[.]{.period}]{.codenumber}[
]{.space}Some cobweb plots](images/logistic_cobwebs.svg){.contained}

It turns out that the process is quite sensitive to the slope of the
function at the point of intersection. A slightly steeper function is
shown in [Figure 2.9]{.xref}(c); we notice that the fixed point now
appears to be repelling. Finally, figure [Figure 2.9]{.xref}(d)
illustrates the fact that all hell can break loose.

Playing with cobweb plots is a great way to get a feel for the
possibilites that arise in discrete dynamical systems. Here\'s an
interactive tool that we\'ll use for this purpose:

<https://marksmath.org/visualization/cobwebs/>

###### [Checkpoint]{.type}[ ]{.space}[2.10]{.codenumber}[.]{.period} {#checkpoint-2.10. .heading}

Plug the function \\(f(x)=\\frac{1}{5}x\^2 - 2x + 6\\) that we played
with in
[Section 2.2](contents.html#section-computer_experimentation "Section 2.2: Computer experimentation"){.internal}
into the [cobweb
tool](https://marksmath.org/visualization/cobwebs/){.external}. Can you
see why we couldn\'t help but find the periodic behavior?
:::

::: {#section-classification_of_fixed_points .section .section}
### [Section]{.type} [2.4]{.codenumber} [Classification of fixed points]{.title} {#section-2.4-classification-of-fixed-points .heading .hide-type}

The cobweb plots in the previous section illustrate that the slope of
the function at the point where it crosses the fixed point might play a
role in the behavior of the iterates near that fixed point. We explore
that further here. First, we explore the simplest situation - functions
with constant slope.

###### [Example]{.type}[ ]{.space}[2.11]{.codenumber}[.]{.period}[ ]{.space}[Linear iteration.]{.title} {#example-2.11.-linear-iteration. .heading}

Suppose that \\(f\\) is a linear function: \\(f(x)=ax\\text{.}\\) It\'s
easy to see that the origin \\(x=0\\) is a fixed point of
\\(f\\text{.}\\) Show that any non-zero initial point \\(x_0\\) moves
away from the origin under the iteration of \\(f\\) whenever \\(\|a\| \>
1\\) but moves towards the origin under iteration of \\(f\\) if \\(\|a\|
\< 1\\text{.}\\)

::: {.solutions}
[[Solution.]{.type}]{#solution-1 .id-ref .solution-knowl .original}

::: {#hk-solution-1 .hidden-content .tex2jax_ignore}
::: {.solution .solution-like}
This is easy, once we recognize that there is a closed form for the
\\(n\^{\\text{th}}\\) iterate of \\(f\\text{,}\\) namely \\(f\^n(x) =
a\^n x\\text{.}\\) Note that cobweb plots for these functions are shown
in [Figure 2.12]{.xref}.

![[Figure]{.type}[ ]{.space}[2.12[.]{.period}]{.codenumber}[
]{.space}Some linear cobweb
plots](images/linear_cobwebs.svg){.contained}
:::
:::
:::

###### [Checkpoint]{.type}[ ]{.space}[2.13]{.codenumber}[.]{.period}[ ]{.space}[Affine iteration.]{.title} {#checkpoint-2.13.-affine-iteration. .heading}

Suppose, that \\(f\\) is an *affine function*, which just means that it
has the form \\(f(x)=ax+b\\text{,}\\) where \\(a\\neq 0\\text{.}\\)
Suppose also that \\(x_0\\in\\mathbb R\\) and let\'s consider the
iterates \\(x\_{n+1} = f(x_n)\\)

1.  ::: {#li-29}
    Show that \\(f\\) has a unique fixed point iff \\(a\\neq
    1\\text{.}\\) What if \\(a=1\\text{?}\\)
    :::

2.  ::: {#li-30}
    Suppose that \\(\|a\| \< 1\\text{.}\\) Show that the sequence of
    iterates converges to the fixed point of \\(f\\text{.}\\)
    :::

3.  ::: {#li-31}
    Suppose that \\(\|a\| \> 1\\text{.}\\) Show that the sequence of
    iterates diverges.
    :::

4.  ::: {#li-32}
    What happens if \\(a=-1\\text{?}\\)
    :::

Example [Example 2.11]{.xref} and exercise [Checkpoint 2.13]{.xref}
together classify the dynamical behavior of first order polynomials
completely and show that their behavior is fairly simple. For that
reason, we focus on polynomials of degree two and higher. Already in the
quadratic case, we can find much more complicated and interesting
behavior. Motivated by the behavior we see in linear and affine
functions, we make the following defintion.

###### [Definition]{.type}[ ]{.space}[2.14]{.codenumber}[.]{.period} {#definition-2.14. .heading}

Let \\(f:\\mathbb R \\to \\mathbb R\\) be continuously differentiable
and suppose that \\(x_0\\in\\mathbb R\\) is a fixed point of
\\(f\\text{.}\\) Then we classify \\(x_0\\) as

1.  ::: {#li-33}
    *attractive*, if \\(0 \< \|f\'(x_0)\| \< 1\\text{,}\\)
    :::

2.  ::: {#li-34}
    *super-attractive*, if \\(f\'(x_0) = 0\\text{,}\\)
    :::

3.  ::: {#li-35}
    *repulsive* or *repelling*, if \\(\|f\'(x_0)\| \> 1\\text{,}\\) or
    :::

4.  ::: {#li-36}
    *neutral*, if \\(\|f\'(x_0)\| = 1\\text{,}\\)
    :::

The number, \\(f\'(x_0)\\) is called the *multiplier* for the fixed
point. If, in the attractive case, the multiplier is zero, we say that
\\(x_0\\) is *super-attractive*.

The following theorem justifies this notation.

###### [Theorem]{.type}[ ]{.space}[2.15]{.codenumber}[.]{.period} {#theorem-2.15. .heading}

Let \\(f:\\mathbb R \\to \\mathbb R\\) be continuously differentiable
and suppose that \\(x_0\\in\\mathbb R\\) is a fixed point of
\\(f\\text{.}\\)

1.  ::: {#li-37}
    If \\(x_0\\) is an attractive or super-attractive fixed point for
    \\(f\\text{,}\\) then there is an \\(\\varepsilon \> 0\\) such that
    the orbit of \\(x\\) under iteration of \\(f\\) tends to \\(x_0\\)
    for every \\(x\\) such that \\(\|x-x_0\| \< \\varepsilon\\text{.}\\)
    :::

2.  ::: {#li-38}
    If \\(x_0\\) is a repelling fixed point for \\(f\\text{,}\\) then
    there is an \\(\\varepsilon \> 0\\) such that the orbit of \\(x\\)
    under iteration of \\(f\\) tends (initially) away from \\(x_0\\) for
    every \\(x\\) such that \\(\|x-x_0\| \< \\varepsilon\\text{.}\\)
    :::

###### [Proof[.]{.period}]{.type} {#proof. .heading}

We prove part one; the second part is similar. Since
\\(\|f\'(x_0)\|\<1\\) and \\(f\'\\) is continuous, we may choose an
\\(\\varepsilon\>0\\) and a postive number \\(r\<1\\) such that
\\(\|f\'(x)\|\<r\\) for all \\(x\\) such that \\(\|x-x_0\| \<
\\varepsilon\\text{.}\\) Then, given \\(x\\) such that \\(\|x-x_0\| \<
\\varepsilon\\text{,}\\) we can apply the Mean Value Theorem to obtain a
number \\(c\\) such that

::: {.displaymath}
\\begin{equation\*} \|f(x)-x_0\| = \|f(x)-f(x_0)\| = \|f\'(c)\|\|x-x_0\|
\\leq r\\varepsilon. \\end{equation\*}
:::

By induction, we can show that

::: {.displaymath}
\\begin{equation\*} \|f\^n(x)-x_0\| \\leq r\^n\\varepsilon.
\\end{equation\*}
:::

The result follows, since \\(r\^n\\varepsilon \\to 0\\) as
\\(n\\to\\infty\\text{.}\\)

From the proof, we see that \\(x_n\\to x_0\\) exponentially and that the
magnitude of \\(\|f\'(x_0)\|\\) dictates the base of that exponential.
When \\(f\'(x_0)=0\\text{,}\\) the rate is faster than exponential.

###### [Example]{.type}[ ]{.space}[2.16]{.codenumber}[.]{.period} {#example-2.16. .heading}

The function \\(f(x)=4.8\\,x\^2(1-x)\\) is graphed in
[Figure 2.17]{.xref}, along with the line \\(y=x\\text{.}\\) The points
of intersection are fixed points and, from left to right, they are
super-attractive, repulsive, and attractive. The reader should consider
the appearance of a cobweb plot for initial values starting near each of
those fixed points.

![[Figure]{.type}[ ]{.space}[2.17[.]{.period}]{.codenumber}[
]{.space}Three types of fixed
points](images/three_fixed.svg){.contained}

The behavior of iterates near a neutral fixed point can be more varied.

###### [Checkpoint]{.type}[ ]{.space}[2.18]{.codenumber}[.]{.period}[ ]{.space}[Dynamical behavior near neutral fixed points.]{.title} {#checkpoint-2.18.-dynamical-behavior-near-neutral-fixed-points. .heading}

For each of the following scenarios, find an example of a function
\\(f:\\mathbb R\\to \\mathbb R\\) and a fixed point \\(x_0\\) of \\(f\\)
satisfying that scenario.

1.  ::: {#li-39}
    There is an \\(\\varepsilon \> 0\\) such that the orbit of \\(x\\)
    tends to \\(x_0\\) for all \\(x\\) such that \\(\|x-x_0\| \<
    \\varepsilon\\text{.}\\)
    :::

2.  ::: {#li-40}
    There is an \\(\\varepsilon \> 0\\) such that the orbit of \\(x\\)
    tends initially away from \\(x_0\\) for all \\(x\\) such that
    \\(\|x-x_0\| \< \\varepsilon\\text{.}\\)
    :::

3.  ::: {#li-41}
    There is an \\(\\varepsilon \> 0\\) such that the orbit of \\(x\\)
    tends to \\(x_0\\) for all \\(x\\) such that \\(0 \< x-x_0 \<
    \\varepsilon\\) but the orbit of \\(x\\) tends initially away from
    \\(x_0\\) for all \\(x\\) such that \\(0 \< x_0-x \<
    \\varepsilon\\text{.}\\)
    :::

4.  ::: {#li-42}
    There is an \\(\\varepsilon \> 0\\) such that the orbit of \\(x\\)
    tends to \\(x_0\\) for all \\(x\\) such that \\(0 \< x-x_0 \<
    \\varepsilon\\) but the orbit of \\(x\\) tends initially away from
    \\(x_0\\) for all \\(x\\) such that \\(0 \< x_0-x \<
    \\varepsilon\\text{.}\\)
    :::
:::

::: {#section-7 .section .section}
### [Section]{.type} [2.5]{.codenumber} [Classification of periodic orbits]{.title} {#section-2.5-classification-of-periodic-orbits .heading .hide-type}

As mentioned right after [the example on periodicty 2.6]{.xref}, a
periodic point for \\(f\\) of period \\(n\\) is a fixed point of
\\(f\^n\\text{.}\\) Treating the points of a periodic orbit this way
allows us to extend the classification as fixed points to periodic
orbits.

###### [Definition]{.type}[ ]{.space}[2.19]{.codenumber}[.]{.period} {#definition-2.19. .heading}

Let \\(f:\\mathbb R \\to \\mathbb R\\) be continuously differentiable
and suppose that \\(x_0\\in\\mathbb R\\) is a periodic point of \\(f\\)
with period \\(n\\text{.}\\) Let \\(F=f\^n\\text{.}\\) We classify
\\(x_0\\) and its orbit as

1.  ::: {#li-43}
    *attractive*, if \\(\|F\'(x_0)\| \< 1\\text{,}\\)
    :::

2.  ::: {#li-44}
    *super-attractive*, if \\(F\'(x_0) =0 \\text{,}\\)
    :::

3.  ::: {#li-45}
    *repulsive* or *repelling*, if \\(\|F\'(x_0)\| \> 1\\text{,}\\) or
    :::

4.  ::: {#li-46}
    *neutral*, if \\(\|F\'(x_0)\| = 1\\text{,}\\)
    :::

The number \\(F\'(x_0)\\) is called the *multiplier* of the orbit. If,
in the attractive case, the multiplier is zero, we say that the orbit is
*super-attractive*.

There is a nice characterization of the multiplier of an orbit that
allows us to compute it without explicitly computing a formula for
\\(f\^n\\text{.}\\)

###### [Lemma]{.type}[ ]{.space}[2.20]{.codenumber}[.]{.period} {#lemma-2.20. .heading}

Suppose that

::: {.displaymath}
\\begin{equation\*} x_0 \\to x_1 \\to x_2 \\to \\cdots \\to x\_{n-1}
\\to x_0 \\end{equation\*}
:::

is an orbit of period \\(n\\) for \\(f:\\mathbb R \\to \\mathbb
R\\text{.}\\) Then the multiplier of the orbit is

::: {.displaymath}
\\begin{equation\*} f\'(x_0)f\'(x_1)\\cdots f\'(x\_{n-1}).
\\end{equation\*}
:::

###### [Proof[.]{.period}]{.type} {#proof.-1 .heading}

First note that for an \\(n=2\\text{,}\\) we can apply the chain rule to
obtain

::: {.displaymath}
\\begin{equation\*} \\frac{d}{dx}f\^2(x) = \\frac{d}{dx}f(f(x)) =
f\'(f(x))f\'(x). \\end{equation\*}
:::

Thus, if \\(x_0 \\to x_1 \\to x_0\\) is an orbit of period two and we
evaluate that equation at \\(x_0\\text{,}\\) we obtain

::: {.displaymath}
\\begin{equation\*} \\left.\\frac{d}{dx}f\^2(x)\\right\|\_{x=x_0} =
f\'(x_1)f\'(x_0). \\end{equation\*}
:::

The result for orbits longer than two can be proven by induction, since

::: {.displaymath}
\\begin{equation\*} \\frac{d}{dx}f\^n(x) = \\frac{d}{dx}f(f\^{n-1}(x)) =
f\'(f\^{n-1}(x)) \\frac{d}{dx}f\^{n-1}(x). \\end{equation\*}
:::

Note that the only way the product in [Lemma 2.20]{.xref} is zero, is if
one of the terms is zero. This yields the following corollary.

###### [Corollary]{.type}[ ]{.space}[2.21]{.codenumber}[.]{.period} {#corollary-2.21. .heading}

A periodic orbit is super-attracting if and only if it contains a
critical point.

###### [Example]{.type}[ ]{.space}[2.22]{.codenumber}[.]{.period} {#example-2.22. .heading}

Let \\(f(x) = x\^2-1\\text{.}\\) Note that \\(f(0)=-1\\) and
\\(f(-1)=0\\) so that \\(0\\to1\\to0\\) forms an orbit of period 2. To
see if this orbit is attractive, we examine

::: {.displaymath}
\\begin{equation\*} F(x) = f(f(x)) = (x\^2-1)\^2-1 = x\^4-x\^2.
\\end{equation\*}
:::

Note that \\(F\'(0)=0\\) and \\(F\'(-1)=0\\text{;}\\) thus, the orbit is
super-attractive.

The plots of \\(f\\) and \\(f\^2\\text{,}\\) together with
\\(y=x\\text{,}\\) are shown in [Figure 2.23]{.xref}. Note that \\(f\\)
has two fixed points shown in red. They can found by solving the
equation \\(x\^2-1=x\\) and they are both repulsive under iteration of
\\(f\\text{.}\\) The two super-attractive orbits of \\(f\^2\\) are shown
in green.

![[Figure]{.type}[ ]{.space}[2.23[.]{.period}]{.codenumber}[ ]{.space}An
attractive orbit of period
two](images/attractive_period_two.svg){.contained}
:::

::: {#section-parameterized_families .section .section}
### [Section]{.type} [2.6]{.codenumber} [Parameterized families of functions]{.title} {#section-2.6-parameterized-families-of-functions .heading .hide-type}

::: {#introduction-10 .section .introduction}
Rather than explore the behavior of a single function at a time, we can
introduce a parameter and explore the range of behavior that arises in a
whole family of functions. Two important examples are

1.  ::: {#li-47}
    *The quadratic family*: \\(f_c(x)=x\^2+c\\)
    :::

2.  ::: {#li-48}
    *The logistic family*: \\(f\_{\\lambda}(x)=\\lambda x(1-x)\\)
    :::

The cobweb plots shown back in [Figure 2.9]{.xref} are all chosen from
the logistic family with \\(\\lambda=2.8\\text{,}\\)
\\(\\lambda=3.2\\text{,}\\) and \\(\\lambda=4\\text{.}\\) Even in those
three pictures with graphs that look so very similar, we see three
different types of behavior: an attractive fixed point, an attractive
orbit of period two, and chaos (which can be given a very technical
meaning).

[Figure 2.24]{.xref} shows some cobweb plots for the quadratic family of
functions. Note that the behavior we see is very similar to the behavior
we see for the logistic family - a fact that will become more
understandable once we study conjugacy in section
[Section 2.7](contents.html#section-conjugacy "Section 2.7: Conjugacy"){.internal}

![[Figure]{.type}[ ]{.space}[2.24[.]{.period}]{.codenumber}[
]{.space}Some cobweb plots for the quadratic
family](images/quadratic_cobwebs.svg){.contained}
:::

::: {#subsection-9 .section .subsection}
#### [Subsection]{.type} [2.6.1]{.codenumber} [The bifurcation diagram]{.title} {#subsection-2.6.1-the-bifurcation-diagram .heading .hide-type}

A fabulous illustration of the types of behavior that can arise in a
family of functions indexed by a single parameter and each with a single
critical point can be generated as follows: For each value of the
parameter, compute a large number points of the orbit of the critical
point (maybe 1000 iterates). Since we\'re interested in long term
behavior, rather than any transient behavior, discard the first few
iterates (maybe 100). Then, plot the remaining points in a vertical
column at the horizontal position indicated by the parameter.

The orbit of a critical point is called a *critical orbit* and its
importance is due to the following theorem.

###### [Theorem]{.type}[ ]{.space}[2.25]{.codenumber}[.]{.period} {#theorem-2.25. .heading}

If \\(f:\\mathbb C \\to \\mathbb C\\) has an attractive or
super-attractive orbit, then that orbit must attract at least one
critical point.

Note that this is really a theorem of complex dynamics. There is an
analogous statement for real dynamics but it\'s a bit more complicated
and its proof takes us a bit farther astray than we want. This is a
great example of complex analysis being, in some ways, more elegant than
real analysis.

Regardless, the theorem has important implications for real iteration.
For example, a polynomial of degree \\(n\\) can have at most \\(n-1\\)
attractive orbits. Furthermore, if all the critical points happen to be
real, we can find all the attractive behavior by simply iterating from
the critical points. If we do this systematically for the quadratic
family, plotting the columns to generate the bifurcation diagram, we get
[Figure 2.26]{.xref}

![[Figure]{.type}[ ]{.space}[2.26[.]{.period}]{.codenumber}[
]{.space}The bifurcation diagram for the quadratic
family](images/quadratic_bifurcation.png){.contained}

We can interpret this diagram as follows:

-   ::: {#li-49}
    For \\(-0.75 \< c \< 0\\text{,}\\) there is an attractive fixed
    point.
    :::

-   ::: {#li-50}
    For \\(-1.25 \< c \< -0.75\\text{,}\\) there is an attractive orbit
    of period \\(2\\text{.}\\)
    :::

-   ::: {#li-51}
    As \\(c\\) passes from just above \\(-0.75\\) to just below
    \\(-0.75\\text{,}\\) the dynamics of \\(f_c\\) undergo a
    *bifurcation*.
    :::

-   ::: {#li-52}
    For \\(c\\) just a little less than \\(-1.25\\text{,}\\) there is an
    attractive orbit of period four. This orbit bifurcates soon into an
    attractive orbit of period 8. It appears that this behavior
    continues as \\(c\\) decreases.
    :::

-   ::: {#li-53}
    For \\(c\\) somewhere around \\(c\\approx -1.4\\text{,}\\) the
    period doubling appears to stop and we get more complicated
    behavior.
    :::

Generally, a bifurcation occurs at a parameter value \\(c=c_0\\) if the
global dynamical behavior of the function \\(f_c\\) undergoes some
qualitative change as \\(c\\) passes through \\(c_0\\text{.}\\) There
are number of different types of bifurcations that can occur, depending
on the nature of the qualitative behavior under consideration. The
bifurcations that are evident in [Figure 2.26]{.xref} in the range
\\(-1.4 \< c \< 0\\) are called *period doubling bifurcations*.
:::

::: {#subsection-10 .section .subsection}
#### [Subsection]{.type} [2.6.2]{.codenumber} [The period doubling cascade]{.title} {#subsection-2.6.2-the-period-doubling-cascade .heading .hide-type}

Let\'s work towards a deeper, theoretical understanding of the period
doubling that we see in the bifurcation diagram of [Figure 2.26]{.xref}.
Again, we are dealing with the family of functions \\(f_c(x) =
x\^2+c\\text{.}\\) For \\(c\\) just a bit larger than \\(-0.75\\) it
appears that we have an attractive fixed point while, for \\(c\\) just a
bit smaller than \\(-0.75\\text{,}\\) it appears that we have an
attracting orbit of period two. Why, exactly does this happen?

First, let\'s explore the fixed points of \\(f_c\\text{;}\\) we can find
them by solving \\(f_c(x)=x\\text{:}\\)

::: {.displaymath}
\\begin{equation\*} x\^2+c = x \\: \\Longleftrightarrow \\: x\^2-x+c =
0. \\end{equation\*}
:::

Applying the quadratic formula, we find

::: {.displaymath}
\\begin{equation\*} x = \\frac{1\\pm\\sqrt{1-4c}}{2}. \\end{equation\*}
:::

For \\(c \< 1/4\\text{,}\\) we have two real fixed points but a glance
at the graphs from [Figure 2.24]{.xref} shows that it\'s the smaller of
these two fixed points we\'re interested in. Of course,
\\(f\'(x)=2x\\text{,}\\) so the value of the derivative at the smaller
fixed point is \\(1-\\sqrt{1-4c}\\text{.}\\) Plugging \\(c=-3/4\\) into
this formula, we find that this is \\(-1\\text{.}\\) For \\(c\\)
slightly larger than \\(-3/4\\text{,}\\) this is bigger than \\(-1\\)
and for \\(c\\) slightly smaller than \\(-3/4\\text{,}\\) this is
smaller than \\(-1\\text{.}\\) This explains why we have an attractive
fixed point for \\(c\\) slightly larger than \\(-3/4\\) that is no
longer attractive once \\(c\\) passes below \\(-3/4\\text{.}\\)

Now, we ask - why does the attractive orbit of period two appear as the
attractive fixed point disappears? To see this, we consider the function

::: {.displaymath}
\\begin{equation\*} F_c(x) = f_c\\circ f_c(x) = (x\^2+c)\^2+c = x\^4 +
2cx\^2+(c\^2+c). \\end{equation\*}
:::

We are interested in the fixed points, thus we must solve

::: {.displaymath}
\\begin{equation} x\^4 + 2cx\^2+(c\^2+c) = x \\: \\text{ or } \\: x\^4 +
2cx\^2 - x + (c\^2+c) = 0.\\label{equation-f_squared}\\tag{2.1}
\\end{equation}
:::

Here is an observation that helps us factor this polynomial: Any point
that is fixed by \\(f_c\\) must also be fixed by \\(F_c\\text{.}\\)
Thus, we expect \\(x\^2+c-x\\) to be a factor of the polynomial in
[(2.1)]{.xref}. Using this, we find that

::: {.displaymath}
\\begin{equation\*} x\^4 + 2cx\^2 - x + (c\^2+c) = (x\^2 - x + c)(x\^2 +
x + c + 1). \\end{equation\*}
:::

We can then apply the quadratic formula to get the two new fixed points
of \\(F_c\\text{,}\\) namely

::: {.displaymath}
\\begin{equation\*} x = \\frac{-1 \\pm \\sqrt{1-4(c+1)}}{2} = \\frac{-1
\\pm \\sqrt{-(3+4c)}}{2}. \\end{equation\*}
:::

These two points form an orbit of period two for \\(f_c\\text{.}\\)
Since \\(f_c\'(x)=2x\\) we can multiply those points by two and multiply
the results to get the multiplier for the orbit. The result is:

::: {.displaymath}
\\begin{equation\*} (-1+\\sqrt{-(3+4c)})(-1-\\sqrt{-(3+4c)}) = 4+4c.
\\end{equation\*}
:::

When \\(c=-3/4\\text{,}\\) the multiplier is \\(1\\text{.}\\) For
\\(c\\) a little less than \\(-3/4\\text{,}\\) the multiplier is a
little less than one. Hence the orbit has become attractive.

A nice way to visualize this is to plot \\(f_c\^2\\) together with
\\(f_c\\) and \\(y=x\\) on the same set of axes for a few different
choices of \\(c\\text{.}\\) This is shown in [Figure 2.27]{.xref} where
we can see exactly how The fixed point went from attractive to repulsive
while an attractive orbit of period two showed up as \\(c\\) passed
below \\(-0.75\\text{.}\\)

![[Figure]{.type}[ ]{.space}[2.27[.]{.period}]{.codenumber}[
]{.space}Bifurcation](images/cascading_cobwebs.svg){.contained}

Note that our [cobweb
tool](https://marksmath.org/visualization/cobwebs/){.external} allows
you to plot iterates of \\(f\\) on the plot to assist in this type of
analysis.

###### [Checkpoint]{.type}[ ]{.space}[2.28]{.codenumber}[.]{.period} {#checkpoint-2.28. .heading}

Consider the logistic family \\(f\_{\\lambda}(x) = \\lambda
x(1-x)\\text{.}\\)

1.  ::: {#li-54}
    Using our [cobweb
    tool](https://marksmath.org/visualization/cobwebs/){.external}
    :::
:::
:::

::: {#section-conjugacy .section .section}
### [Section]{.type} [2.7]{.codenumber} [Conjugacy]{.title} {#section-2.7-conjugacy .heading .hide-type}

[Figure 2.9]{.xref} and [Figure 2.24]{.xref} show that the iterative
behavior of the logistic family and the quadratic family are very
similar. In a sense, they are identical. We make that notion precise in
this section.

###### [Definition]{.type}[ ]{.space}[2.29]{.codenumber}[.]{.period}[ ]{.space}[Conjugacy.]{.title} {#definition-2.29.-conjugacy. .heading}

Let \\(S\\) and \\(T\\) be sets and suppose that \\(f:S\\to S\\) and
\\(g:T\\to T\\text{.}\\) We say that \\(f\\) is *semi-conjugate* to
\\(g\\) if there is a surjective function \\(\\varphi:T\\to S\\) such
that

::: {.displaymath}
\\begin{equation\*} f\\circ \\varphi = \\varphi \\circ g.
\\end{equation\*}
:::

The function \\(\\varphi\\) is called a *semi-conjugacy*. In the case
that \\(\\varphi\\) is bijective, then we say that \\(\\varphi\\) is a
conjugacy and that \\(f\\) and \\(g\\) are conjugate.

A geo-symbolic way to remember the semi-conjugation formula is in the
form of a commutative diagram:

::: {.displaymath}
\\begin{equation\*} \\begin{array}\[c\]{ccc}
T&\\stackrel{g}{\\longrightarrow}&T\\\\
\\Big\\downarrow\\scriptstyle{\\varphi}&&\\Big\\downarrow\\scriptstyle{\\varphi}\\\\
S&\\stackrel{f}{\\longrightarrow}&S \\end{array} \\end{equation\*}
:::

The formula states if you follow the arrows from the upper left to the
lower right in either direction, you get the same result.

An immediate consequence of the definition of conjugacy is

::: {.displaymath}
\\begin{equation\*} f\^2\\circ \\varphi = f\\circ f\\circ\\varphi =
f\\circ\\varphi\\circ g = \\varphi\\circ g\\circ g = \\varphi\\circ g\^2
\\end{equation\*}
:::

and, by induction

::: {.displaymath}
\\begin{equation\*} f\^n\\circ \\varphi = \\varphi\\circ g\^n.
\\end{equation\*}
:::

As a result, if \\((t_i)\\) is an orbit of \\(g\\text{,}\\) then
\\((\\varphi(t_i))\\) is an orbit of \\(f\\text{.}\\)

Generally, the nicer \\(\\varphi\\) is, the closer the relationship
between the dynamics of \\(f\\) and the dynamics of \\(g\\text{.}\\) If
\\(\\varphi\\) is bijective, then the relationship is quite close. If
\\(\\varphi\\) is continuous with continuous inverse, then topological
properties of the orbits will be preserved. If \\(S\\) and \\(T\\) are
sets of real or complex numbers and \\(\\varphi(x)=ax+b\\text{,}\\) then
an orbit of one function will be geometrically similar to an orbit of
the other. The dynamical systems are truly identical, up to a scaling.

###### [Example]{.type}[ ]{.space}[2.30]{.codenumber}[.]{.period} {#example-2.30. .heading}

Show that \\(f(x) = x\^2-1\\) is conjugate to \\(g(x) =
\\frac{1}{2}{x\^2}+2x-2\\) via the conjugacy
\\(\\varphi(x)=\\frac{1}{2}x+1\\text{.}\\)

::: {.solutions}
[[Solution.]{.type}]{#solution-2 .id-ref .solution-knowl .original}

::: {#hk-solution-2 .hidden-content .tex2jax_ignore}
::: {.solution .solution-like}
We simply compute

::: {.displaymath}
\\begin{align\*} f(\\varphi(x)) &= \\left(\\frac{1}{2}x+1\\right)\^2 - 1
= \\frac{1}{4}x\^2 + x\\\\ \\varphi(g(x)) &=
\\frac{1}{2}\\left(\\frac{1}{2}{x\^2}+2x-2\\right)+1 = \\frac{1}{4}x\^2
+ x. \\end{align\*}
:::

[Figure 2.31]{.xref} illustrates the similarity between the two
functions.

![[Figure]{.type}[ ]{.space}[2.31[.]{.period}]{.codenumber}[
]{.space}Cobweb plots for conjugate
functions](images/conjugate_cobwebs.svg){.contained}
:::
:::
:::

If you suspect that \\(f\\) is conjugate to \\(g\\) via a conjugacy of
the form \\(\\varphi(x)=ax+b\\text{,}\\) then you can find that
conjugacy by setting \\(f(\\varphi(x)) = \\varphi(g(x))\\text{.}\\) If
you compare coefficients, you should get a system of equations that you
can solve for \\(a\\) and \\(b\\) yielding the conjugacy.

###### [Checkpoint]{.type}[ ]{.space}[2.32]{.codenumber}[.]{.period} {#checkpoint-2.32. .heading}

Find a conjugacy of the form \\(\\varphi(x)=ax+b\\) from
\\(f(x)=x\^2-2\\) to \\(g(x)=4x(1-x)\\text{.}\\)

Exercise [Checkpoint 2.32]{.xref} can be generalized. In fact, the
quadratic family for \\(-2\\leq c \\leq 1/4\\) is identical to the
logistic family for \\(1 \\leq \\lambda \\leq 4\\text{.}\\)

###### [Checkpoint]{.type}[ ]{.space}[2.33]{.codenumber}[.]{.period} {#checkpoint-2.33. .heading}

Show that \\(f(x)=x\^2+(2\\lambda-\\lambda\^2)/4\\) is conjugate to
\\(g(x)=\\lambda x(1-x)\\) via the conjugacy \\(\\varphi(x) = -\\lambda
x + \\lambda/2\\text{.}\\)
:::

::: {#section-chaos_and_doubling .section .section}
### [Section]{.type} [2.8]{.codenumber} [The doubling map and chaos]{.title} {#section-2.8-the-doubling-map-and-chaos .heading .hide-type}

::: {#introduction-11 .section .introduction}
A glance at the cobweb plots of \\(f(x)=x\^2-2\\) and \\(g(x)=4x(1-x)\\)
shows that they both exhibit very complicated behavior. In fact, they
are chaotic in a perfectly quantitative sense. In this section, we\'ll
introduce the doubling map, which is (in a sense) the prototypical
chaotic map. After seeing why it\'s chaotic, we\'ll show that it\'s
conjugate to \\(f(x)=x\^2-2\\text{,}\\) implying that it too is chaotic.
:::

::: {#subsection-doubling_map .section .subsection}
#### [Subsection]{.type} [2.8.1]{.codenumber} [The doubling map]{.title} {#subsection-2.8.1-the-doubling-map .heading .hide-type}

Let \\(H\\) denote the half-open, half-closed unit interval:

::: {.displaymath}
\\begin{equation\*} H = \[0,1) = \\{x\\in\\mathbb R: 0\\leq x \< 1\\}.
\\end{equation\*}
:::

The doubling map \\(d\\) is the function \\(d:H\\to H\\) defined by

::: {.displaymath}
\\begin{equation\*} d(x) = 2x \\bmod 1. \\end{equation\*}
:::

A graph of the doubling map together with a typical cobweb plot starting
at an irrational number is shown in [Figure 2.34]{.xref}

![[Figure]{.type}[ ]{.space}[2.34[.]{.period}]{.codenumber}[
]{.space}The doubling map](images/doubling_map.svg){.contained}

As it turns out, the doubling map is particularly easy to analyze if we
consider its effect on the binary representation of a number. Suppose
that \\(x\\in H\\) has binary representation

::: {.displaymath}
\\begin{equation\*} x = 0\_{\\dot 2}b_1 b_2 b_3 b_4 b_5 \\cdots,
\\end{equation\*}
:::

where each \\(b_i\\) is a zero or a one. (In computer parlance, the
\\(b_i\\)s are called the *bits* of the number.)

Now, the effect of \\(d\\) on the binary representation of \\(x\\) is
simple:

::: {.displaymath}
\\begin{equation\*} d(x) = 0\_{\\dot 2}b_2 b_3 b_4 b_5 \\cdots.
\\end{equation\*}
:::

That is, the effect of \\(d\\) is to simply shift the bits of \\(x\\) to
the left, discarding the bit that shifted into the ones place.

Of course, some numbers have multiple binary representations. For
example,

::: {.displaymath}
\\begin{equation\*} 0\_{\\dot 2}1 = 0\_{\\dot 2}0\\overline{1} =
\\frac{1}{2}, \\end{equation\*}
:::

The doubling map, though, is defined independently of the binary
representation of the number. Thus, we would expect that the shift
operation, when applied to different representations of the same number,
should lead to the same result. For example, the shift operation when
applied to the two representations of \\(1/2\\) above yield.

::: {.displaymath}
\\begin{equation\*} 0\_{\\dot 2}\\overline{0} = 0\_{\\dot
2}\\overline{1} = 0 \\mod 1. \\end{equation\*}
:::

This observation makes it very easy to find orbits with specific
properties. Suppose, for example, we want an orbit of period 3. Simply
pick (almost) any number of the form

::: {.displaymath}
\\begin{equation\*} x = 0\_{\\dot 2}\\overline{b_1 b_2 b_3}
\\end{equation\*}
:::

The only caveat is that we can\'t have all \\(b_i\\)s the same for that
would lead to either zero (which is fixed) or one (which is not in
\\(H\\)). As a concrete example,

::: {.displaymath}
\\begin{equation\*} x = 0\_{\\dot 2}\\overline{001} =
\\sum\_{k=1}\^{\\infty}\\frac{1}{8\^k}=\\frac{1}{7} \\end{equation\*}
:::

has period 3. In fact, it\'s easy to verify that

::: {.displaymath}
\\begin{equation\*} \\frac{1}{7} \\to \\frac{2}{7} \\to \\frac{4}{7}
\\to \\frac{8}{7} = \\frac{1}{7} \\bmod 1 \\end{equation\*}
:::

under the doubling map.

Another nice feature of this representation is that there is a simple
correspondence between the binary expansion of a number and its position
in the unit interval. Every number with a binary expansion starting with
a zero lies in the left half of the unit interval, while every number
starting with a one lies in the right half. The first two bits of a
number specify in which quarter of the interval the number lies; the
first three bits specify in which eighth of the unit interval the number
lies, as shown in [Figure 2.35]{.xref}

![[Figure]{.type}[ ]{.space}[2.35[.]{.period}]{.codenumber}[
]{.space}Dyadic intervals](images/dyadic_intervals.svg){.contained}

More generally, given \\(n\\in\\mathbb N\\text{,}\\) we can break the
unit interval up into \\(n\\) pieces with length \\(1/2\^n\\) and
endpoints \\(i/2\^n\\) for \\(i=0,1,\\ldots,2\^n\\text{.}\\) These are
called *dyadic intervals* and their endpoints (number of the form
\\(1/2\^n\\)) are called dyadic rationals. The first \\(n\\) bits of a
number specify in which \\(n\^{\\text{th}}\\) level dyadic interval that
number lies. In fact, the left hand endpoint of a dyadic interval has a
terminating binary expansion which tells you exactly the first \\(n\\)
bits of all the points in that interval.

Now, suppose that

::: {.displaymath}
\\begin{equation\*} x_1 = 0\_{\\dot 2}b_1 b_2 \\cdots b_n b\_{n+1}
b\_{n+2}\'\\cdots \\: \\text{ and } \\: x_2 = 0\_{\\dot 2}b_1 b_2
\\cdots b_n b\_{n+1}\' b\_{n+2}\'\\cdots. \\end{equation\*}
:::

Thus, the binary expansions of \\(x_1\\) and \\(x_2\\) agree up to at
least the \\(n\^{\\text{th}}\\) spot but potentially disagree after
that. Then, our geometric understanding of dyadic intervals allows us to
easily see that,

::: {.displaymath}
\\begin{equation\*} \|x_1-x_2\|\\leq\\frac{1}{2\^n}. \\end{equation\*}
:::

Of course, there\'s also a simple algebraic proof of this fact, based on
the fact that the bits cancel for \\(k\\leq n\\)

::: {.displaymath}
\\begin{align\*} \|x_1 - x_2\| &=
\\left\|\\sum\_{k=n+1}\^{\\infty}\\frac{b_k-b_k\'}{2\^k}\\right\|\\\\
&\\leq \\sum\_{k=n+1}\^{\\infty}\\frac{\|b_k-b_k\'\|}{2\^k} \\leq
\\sum\_{k=n+1}\^{\\infty}\\frac{1}{2\^k} = \\frac{1}{2\^n}.
\\end{align\*}
:::
:::

::: {#subsection-chaos .section .subsection}
#### [Subsection]{.type} [2.8.2]{.codenumber} [Chaos]{.title} {#subsection-2.8.2-chaos .heading .hide-type}

We can now prove three claims about the doubling map that, together,
assert that the doubling map displays some of the essential features of
chaos. First, we\'ll need to state and prove a lemma.

###### [Lemma]{.type}[ ]{.space}[2.36]{.codenumber}[.]{.period} {#lemma-2.36. .heading}

Suppose that

::: {.displaymath}
\\begin{equation\*} x=0\_{\\dot 2}b_1 b_2 b_3 \\cdots \\: \\text{ and }
\\: y=0\_{\\dot 2}b_1\' b_2\' b_3\' \\cdots \\end{equation\*}
:::

are elements of \\(H\\) that satisfy \\(b_1\\neq b_1\'\\) but
\\(b_2=b_2\'\\text{.}\\) Then \\(\|x-y\| \\geq 1/4\\text{.}\\)

###### [Proof[.]{.period}]{.type} {#proof.-2 .heading}

Computing the difference using the binary representations, taking into
account that the terms disagree in the first spot and agree in the
second, and finally applying the reverse triangle inequality, we get

::: {.displaymath}
\\begin{align\*} \|x-y\| &= \\left\|\\sum\_{i=1}\^{\\infty}
\\frac{b_i-b_i\'}{2\^n}\\right\| = \\left\|\\pm\\frac{1}{2} +
\\sum\_{i=3}\^{\\infty} \\frac{b_i-b_i\'}{2\^n}\\right\|\\\\ &\\geq
\\left\|\\left\|\\pm\\frac{1}{2}\\right\|-\\left\|\\sum\_{i=3}\^{\\infty}
\\frac{b_i-b_i\'}{2\^n}\\right\|\\right\| \\geq \\left\|\\frac{1}{2} -
\\frac{1}{4}\\right\| = \\frac{1}{4}. \\end{align\*}
:::

A geometric interpretation of this lemma is as follows. The fact that
the two points disagree in the first spot means that they cannot lie in
the same half of \\(H\\text{.}\\) The fact that they do agree in the
second spot means that they lie in the same quarter relative to their
half, as shown in [Figure 2.37]{.xref}. Clearly, any two such points
cannot be within \\(1/4\\) of one another.

![[Figure]{.type}[ ]{.space}[2.37[.]{.period}]{.codenumber}[
]{.space}Possible positions of points in lemma
[Lemma 2.36]{.xref}](images/distance_one_fourth.svg){.contained}

###### [Claim]{.type}[ ]{.space}[2.38]{.codenumber}[.]{.period}[ ]{.space}[Sensitive dependence on initial conditions.]{.title} {#claim-2.38.-sensitive-dependence-on-initial-conditions. .heading}

For every \\(x\\in H\\) and for every \\(\\varepsilon \> 0\\text{,}\\)
there is some \\(y\\in H\\) and an \\(n\\in\\mathbb N\\) such that
\\(\|x-y\| \< \\varepsilon\\) yet \\(\|d\^n(x)-d\^n(y)\| \\geq
1/4\\text{.}\\)

###### [Proof[.]{.period}]{.type} {#proof.-3 .heading}

Choose \\(n\\in\\mathbb N\\) large enough so that \\(1/2\^n \<
\\varepsilon\\text{.}\\) Now suppose that \\(x\\in H\\) has binary
expansion

::: {.displaymath}
\\begin{equation\*} x = 0\_{\\dot 2}b_1 b_2\\cdots b_n b\_{n+1} b\_{n+2}
\\cdots. \\end{equation\*}
:::

Define \\(y\\in H\\) so that

::: {.displaymath}
\\begin{equation\*} y = 0\_{\\dot 2}b_1 b_2\\cdots b_n (1-b\_{n+1})
b\_{n+2} \\cdots. \\end{equation\*}
:::

That is, the bits of \\(y\\) agree with those of \\(x\\) in the first
\\(n\\) spots, disagree with \\(x\\) in the \\((n+1)\^{\\text{st}}\\)
spot, and finally agree with \\(x\\) again in the
\\((n+2)\^{\\text{nd}}\\) spot.

Then, the numbers \\(d\^n(x)\\) and \\(d\^n(y)\\) satisfy the hypotheses
of lemma [Lemma 2.36]{.xref}, thus \\(\|d\^n(x)-d\^n(y)\| \\geq
1/4\\text{.}\\)

###### [Claim]{.type}[ ]{.space}[2.39]{.codenumber}[.]{.period}[ ]{.space}[Denseness of periodic orbits.]{.title} {#claim-2.39.-denseness-of-periodic-orbits. .heading}

For every open interval \\(I\\subset H\\text{,}\\) there is some
periodic orbit with an element in \\(I\\text{.}\\)

###### [Proof[.]{.period}]{.type} {#proof.-4 .heading}

Let \\(x\\in I\\) and choose \\(n\\in\\mathbb N\\) large enough so that

::: {.displaymath}
\\begin{equation\*} (x,x+1/2\^n)\\subset I. \\end{equation\*}
:::

Now suppose that

::: {.displaymath}
\\begin{equation\*} x = 0\_{\\dot 2}b_1 b_2\\cdots b_n\\cdots.
\\end{equation\*}
:::

Then,

::: {.displaymath}
\\begin{equation\*} \\hat{x} = 0\_{\\dot 2}\\overline{b_1 b_2\\cdots
b_n} \\end{equation\*}
:::

is a periodic point in \\(I\\text{.}\\)

###### [Claim]{.type}[ ]{.space}[2.40]{.codenumber}[.]{.period}[ ]{.space}[A dense orbit.]{.title} {#claim-2.40.-a-dense-orbit. .heading}

There is a point \\(x\\in H\\) with the property that, for every open
interval \\(I\\subset H\\text{,}\\) there is some iterate of \\(x\\) in
\\(I\\text{.}\\)

###### [Proof[.]{.period}]{.type} {#proof.-5 .heading}

We\'ll define \\(x\\) by specifying its binary expansion. We begin by
writing down all possible *finite* binary strings:

::: {.displaymath}
\\begin{equation\*} 0,\\,1, \\:\\: 00,\\,01,\\,10,\\,11, \\:\\:
000,\\,001,\\,010,\\,011,\\,100,\\,101,\\,110,\\,111,\\ldots
\\end{equation\*}
:::

We then concatenate these to obtain the binary representation of \\(x\\)

::: {.displaymath}
\\begin{equation\*} x = 0\_{\\dot
2}0\\,1\\,00\\,01\\,10\\,11\\,000\\,001\\,010\\,011\\,100\\,101\\,110\\,111\\ldots
\\end{equation\*}
:::

Now, let \\(I\\subset H\\) be an open interval. We claim that there is
some iterate of \\(x\\) in \\(I\\text{.}\\) To see that, let \\(L\\)
denote the length of \\(I\\) and choose \\(n\\in\\mathbb N\\) large
enough so that

::: {.displaymath}
\\begin{equation\*} \\frac{1}{2\^n} \< \\frac{1}{2}L. \\end{equation\*}
:::

Let \\(i\\) be the smallest integer such that \\(i/2\^n \\in
I\\text{.}\\) Note that we must also have \\((i+1)/2\^n \\in
I\\text{.}\\) Thus, the dyadic interval \\(\[i/2\^n,(i+1)/2\^n)\\) is
wholly contained in \\(I\\) and the first \\(n\\) bits of every point in
that interval agree with \\(i/2\^n\\text{.}\\) So, let

::: {.displaymath}
\\begin{equation\*} \\frac{i}{2\^n} = 0\_{\\dot 2}b_1 b_2 \\cdots b_n
\\end{equation\*}
:::

and note that, by construction, the string \\(b_1 b_2 \\cdots b_n\\)
appears somewhere in the binary expansion of \\(x\\text{.}\\) Thus, we
can apply the doubling function to the point \\(x\\) some number, say
\\(m\\text{,}\\) times to obtain

::: {.displaymath}
\\begin{equation\*} d\^m(x) = 0\_{\\dot 2}b_1 b_2 \\cdots b_n \\cdots.
\\end{equation\*}
:::

The number \\(d\^m(x)\\) is then an iterate of \\(x\\) that lies in
\\(I\\text{.}\\)

While there is no truly universally accepted definition of chaos, claims
[Claim 2.38]{.xref}, [Claim 2.39]{.xref}, and [Claim 2.40]{.xref} are
generally agreed to express some of the essential features of chaos. We
might think of them as representing:

-   ::: {#li-55}
    Instability,
    :::

-   ::: {#li-56}
    Structure, and
    :::

-   ::: {#li-57}
    Indecomposability
    :::
:::

::: {#subsection-chaotic_quadratic .section .subsection}
#### [Subsection]{.type} [2.8.3]{.codenumber} [A chaotic quadratic]{.title} {#subsection-2.8.3-a-chaotic-quadratic .heading .hide-type}

Let \\(f(x)=x\^2-2\\text{.}\\) We now show that \\(f\\) is
semi-conjugate to the doubling map \\(d\\) under the semi-conjugacy
\\(\\varphi(x)=2\\cos(2\\pi x)\\text{.}\\) As a result, \\(\\varphi\\)
maps all the orbit types that \\(d\\) has to an orbit of \\(f\\) with
similar properties. Thus, \\(f\\) is chaotic.

###### [Claim]{.type}[ ]{.space}[2.41]{.codenumber}[.]{.period} {#claim-2.41. .heading}

The map \\(f(x)=x\^2-2\\) is semi-conjugate to the doubling map
\\(d(x)=2x\\bmod1\\) under the semi-conjugacy
\\(\\varphi(x)=2\\cos(2\\pi x)\\text{.}\\)

###### [Proof[.]{.period}]{.type} {#proof.-6 .heading}

We must simply show that \\(f\\circ\\varphi=\\varphi\\circ d\\text{,}\\)
so let\'s compute. First,

::: {.displaymath}
\\begin{equation\*} f(\\varphi(x)) = 2(2\\cos(2\\pi x))\^2 - 2 =
4\\cos\^2(2\\pi x)-2. \\end{equation\*}
:::

Well, that was easy. The next part is a little trickier - we just need
to apply a couple of trig identities and use the fact that we can drop
the mods inside the squared trig functions due to the symmetries of
those functions.

::: {.displaymath}
\\begin{align\*} \\varphi(d(x)) &= 2\\cos(2\\pi(2x \\bmod 1))\\\\ &=
2(\\cos\^2(\\pi (2 x \\bmod 1))-\\sin\^2(\\pi (2 x \\bmod 1)))\\\\ &=
2(\\cos\^2(2\\pi x)-\\sin\^2(2\\pi x))\\\\ &= 2(\\cos\^2(2\\pi
x)-(1-\\cos\^2(2\\pi x)))\\\\ &= 2(2\\cos\^2(2\\pi x)-1)\\\\ &=
4\\cos\^2(2\\pi x)-2 \\end{align\*}
:::

Again, the key fact about semi-conjugacy is that \\(\\varphi\\) maps
orbits of \\(d\\) to orbits of \\(f\\text{.}\\) Thus, since \\(d\\) has
a dense orbit \\(f\\) too has a dense orbit. Here\'s a concrete example
illustrating this idea.

###### [Example]{.type}[ ]{.space}[2.42]{.codenumber}[.]{.period} {#example-2.42. .heading}

Find a point of period 11 for the chaotic quadratic
\\(f(x)=x\^2-2\\text{.}\\)

::: {.solutions}
[[Solution.]{.type}]{#solution-3 .id-ref .solution-knowl .original}

::: {#hk-solution-3 .hidden-content .tex2jax_ignore}
::: {.solution .solution-like}
First, it\'s easy to find an orbit of period 11 for the doubling map.
One example is

::: {.displaymath}
\\begin{equation\*} 0\_{\\dot 2}00000000001 =
\\sum\_{k=1}\^{\\infty}\\frac{1}{2\^{11k}} = \\frac{1}{2047}.
\\end{equation\*}
:::

The point behind conjugacy is that \\(\\varphi(1/2047) =
2\\cos(2\\pi/2047)\\) will be a point of period 11 for \\(f\\text{.}\\)
The reader is advised to check this numerically!
:::
:::
:::
:::
:::

::: {#section-closer_look_at_bifurcation_diagram .section .section}
### [Section]{.type} [2.9]{.codenumber} [A closer look at the bifurcation diagram]{.title} {#section-2.9-a-closer-look-at-the-bifurcation-diagram .heading .hide-type}

::: {#introduction-12 .section .introduction}
The bifurcation diagram of figure [Figure 2.26]{.xref} is truly amazing.
:::
:::

::: {#section-tent_maps .section .section}
### [Section]{.type} [2.10]{.codenumber} [Tent Maps]{.title} {#section-2.10-tent-maps .heading .hide-type}
:::

::: {#section-13 .section .section}
### [Section]{.type} [2.11]{.codenumber} [A few notes on computation]{.title} {#section-2.11-a-few-notes-on-computation .heading .hide-type}

Many of the results in these notes have been illustrated on the computer
and some of the exercises require a computational approach. Whenever
using the computer, it is always wise to examine the results critically.
Here\'s a simple numerical example where things clearly go awry. In it,
we are iterating the function \\(f(x)=x\^2-9.1x+1\\) from the fixed
point \\(x_0=0.1\\text{.}\\) We should generate just a constant
sequence.

::: {#sage-8 .sagecell-python}
:::

Uh-oh!

It must be understood that this is a simple consequence of the nature of
floating point arithmetic. Part of the issue is that the decimal number
\\(0.1\\) or \\(1/10\\) is not exactly representable in binary. In fact,

::: {.displaymath}
\\begin{equation\*} \\frac{1}{10} = 0\_{\\dot2}0\\overline{0011} =
\\frac{1}{2}\\sum\_{k=1}\^{\\infty}\\frac{3}{16\^k}. \\end{equation\*}
:::

Thus, the computer *must* introduce round-off error in the computation.
Furthermore, \\(0.1\\) is a repelling fixed point of the function. Thus,
that round-off error is magnified with each iteration. Our study of
dynamics has illuminated a critical issue in numerical computation!

In the terminology of numerical analysis, computation near an attractive
fixed point is stable while computation near a repelling fixed point is
unstable. Generally speaking, stable computation is trustworthy while
unstable computation is not. The implication for the pictures that we
see here is that illustration of attractive behavior should be just
fine. In [Figure 2.9]{.xref}, for example, images (b) and (c) illustrate
attraction to a fixed point that not only involves stable computation
but also agrees with our theoretical development. We are happy with
those figures. The cobweb plot shown in [Figure 2.9]{.xref} (d),
however, should frankly be viewed with some suspicion.

The same can be said for the bifurcation diagram in
[Figure 2.26]{.xref}. In much of that image, we see a gray smear
indicating chaos. How can we trust that? Well, first, theory tells us
that there really *is* chaos. That is, there are orbits that are dense
in some interval for many \\(c\\) values. Furthermore, much of the image
shows attractive regions and we can be confident in that portion.

In fact, in many of the images that we will generate later - Julia sets,
the Mandelbrot set, and similar images - the stable region dominates.
Thus, we can be confident in overall image because the unstable region
is the complement of the stable region. We might not be confident in
computations involving some particular point, but we can be confident in
the overall picture. (This will, perhaps, be more clear as we move into
complex dynamics.)

Nonetheless, sometimes we want to experiment with genuinely unstable
dynamics. One way to improve our confidence in these kinds of
computations is to use high precision numbers. Consider, for example,
the cobweb plot of the doubling map shown in [Figure 2.34]{.xref}. A
naive approach to generate the first few terms of an orbit associated
with the doubling map might be as follows:

::: {#sage-9 .sagecell-python}
:::

We\'ve reached the fixed point zero and now we\'re stuck! Even if we
iterate 1000 times, we\'ll generate a cobweb plot that looks like
[Figure 2.43]{.xref}

![[Figure]{.type}[ ]{.space}[2.43[.]{.period}]{.codenumber}[ ]{.space}An
inaccurate cobweb plot](images/bad_doubling_cobweb.svg){.contained}

The cobweb plot shown in [Figure 2.34]{.xref} was generated using the
mpmath multi-precision library for Python with code that looked
something like so:

::: {#sage-10 .sagecell-python}
:::

While the truncated output looks the same, note that this was after 1000
iterates. This behavior makes perfect sense if you understand that the
doubling map loses one bit of precision with every iterate.
:::

::: {#exercises-2 .section .exercises}
### [Exercises]{.type} [2.12]{.codenumber} [Exercises]{.title} {#exercises-2.12-exercises .heading .hide-type}

###### [1[.]{.period}]{.codenumber} {#section-6 .heading}

Let \\(f:\\mathbb R\\to \\mathbb R\\) be continuously differentiable. We
say that \\(x_0\\) is a simple root of \\(f\\) if \\(f(x_0)=0\\) and
\\(f\'(x_0)\\neq0\\text{.}\\) Show that if \\(x_0\\) is a simple root of
\\(f\\text{,}\\) then \\(x_0\\) is a super-attracting fixed point of the
Newton\'s method iteration function \\(N\\) for \\(f\\text{.}\\)

###### [2[.]{.period}]{.codenumber} {#section-7 .heading}

Find an example of a continuously differentiable function \\(f:\\mathbb
R\\to \\mathbb R\\) that attracts no critical point.

::: {.solutions}
[[Hint.]{.type}]{#hint-1 .id-ref .hint-knowl .original}

::: {#hk-hint-1 .hidden-content .tex2jax_ignore}
::: {.hint .solution-like}
Draw a graph. Of course, you can\'t violate theorem
[Theorem 2.25]{.xref}.
:::
:::
:::

###### [3[.]{.period}]{.codenumber} {#section-8 .heading}

Let \\(f(x)=x\^2-4x+5\\text{.}\\) Show that \\(f\\) has a
super-attractive orbit of period 2.

###### [4[.]{.period}]{.codenumber} {#section-9 .heading}

Let \\(f(x)=3 x\^2-6 x+3.415\\text{.}\\) Find all attractive orbits of
\\(f\\text{.}\\)

###### [5[.]{.period}]{.codenumber} {#section-10 .heading}

Find a value of \\(c\\) such that \\(f_c(x)=x\^2+c\\) is affinely
conjugate to \\(g(x)=(x-1)(x+2)\\text{.}\\) Show that both functions
have neutral fixed points.

###### [6[.]{.period}]{.codenumber} {#section-11 .heading}

Find an orbit of period 11 for the function \\(g(x)=4x(1-x)\\)

###### [7[.]{.period}]{.codenumber} {#section-12 .heading}

We wish to find a number \\(x_0 \\in H=\[0,1)\\) whose orbit is dense in
\\(H\\) under iteration of \\(g(x)=4x(1-x)\\text{.}\\)

a.  ::: {#li-58}
    Outline a strategy for finding \\(x_0\\text{.}\\)
    :::

b.  ::: {#li-59}
    Find a decimal approximation to \\(x_0\\) that is valid to 10
    decimal places.
    :::
:::
:::
:::
