if(window.innerWidth > 600) {
	var width = window.innerWidth*0.17;
	var height = width, pad = 0;
	var xmin = -0.1, xmax = 1.1;
	var ymin = -0.1, ymax = 1.1;

	var xrange = xmax-xmin;
	var yrange = ymax-ymin;

	var svg = d3.select("main")
		.append("section")
		.attr("class", "sidebar hide-small pure-u-1 pure-u-md-1-4")
		.append("svg")
		//.attr("style", "border: 1px solid black")
		.attr("id", "cobweb_plot")
		.attr("width", width)
		.attr("height", height);

	var xScale = d3.scaleLinear()
		.domain([xmin,xmax])
		.range([pad, width - pad]);
	var yScale = d3.scaleLinear()
		.domain([ymin,ymax])
		.range([height - pad, pad]);
	var rScale = d3.scaleLinear()
		.domain([0,xrange])
		.range([0, width - pad]);
	var xScaleInverse = d3.scaleLinear()
		.range([xmin,xmax])
		.domain([pad,width-pad]);
	var yScaleInverse = d3.scaleLinear()
		.range([ymin,ymax])
		.domain([height - pad, pad]);
	// A convenience function for drawing lines
	var pts_to_path = d3.line()
		.x(function(d) { return xScale(d[0]); })
		.y(function(d) { return yScale(d[1]); })


	// Draw the axes
	svg.append("g").append("path")
		.attr("d", pts_to_path([[xmin,0],[xmax,0]]))
		.attr("stroke", "#333")
		.attr("stroke-width", 0.5)
		.attr("fill", "none");
	svg.append("g").append("path")
		.attr("d", pts_to_path([[0,ymin],[0,ymax]]))
		.attr("stroke", "#333")
		.attr("stroke-width", 0.5)
		.attr("fill", "none");
	// And the tick marks
	var x_ticks = d3.ticks(xmin,xmax,10)
		.map(function(x) {return [[x,0],[x,-yrange/50]]})
	svg.append("g")
		.selectAll("path")
		.data(x_ticks)
		.enter().append("path")
		.attr("d", function(d) {return pts_to_path(d)})
		.attr("stroke", "black")
		.attr("stroke-width", 0.5)
		.attr("class", "ticks");
	var y_ticks = d3.ticks(ymin,ymax,4)
		.map(function(y) {return [[-xrange/80,y],[0,y]]})
	svg.append("g")
		.selectAll("path")
		.data(y_ticks)
		.enter().append("path")
		.attr("d", function(d) {return pts_to_path(d)})
		.attr("stroke", "black")
		.attr("stroke-width", 0.5)
		.attr("class", "ticks");

	// Draw y=x
	svg.append("g")
		.append("path")
		.attr("d", pts_to_path([[xmin,xmin],[xmax,xmax]]))
		.attr("stroke", "black")
		.attr("stroke-width", 1.5);

	function f(x,r) {
		return r*x*(1-x)
	}
	var dd = xrange/30;
	function draw(x0,r) {
		svg.selectAll(".temp").remove();
		svg.append("circle")
				.attr("class", "temp")
				.attr("cx", xScale(x0))
				.attr("cy", yScale(x0))
				.attr("r", rScale(0.02))
				.attr("fill", "#0a0")
				.attr("stroke", "#050")
				.attr("stroke-width", 1);
		var g = svg.insert("g", ":first-child")
			.attr("class", "temp");
		var pts = d3.range(xmin,xmax+dd,dd)
			.map(function(x) {return [x,f(x,r)]});
		g.append("path")
			.attr("d", pts_to_path(pts))
			.attr("stroke", "#333")
			.attr("stroke-width", 2)
			.attr("fill", "none");
		var xi = x0, xip1;
		var cobweb = [[xi,xi]]
		for(var i=0; i<=100; i++) {
			xip1 = f(xi,r);
			cobweb.push([xi,xip1]);
			xi = xip1;
			cobweb.push([xi,xi]);
			g.append("path")
				.attr("d", pts_to_path(cobweb))
				.attr("stroke", "#333")
				.attr("stroke-width", 1)
				.attr("fill", "none")
				.style('opacity', 0.01);
		}
	}

	r_current = 3;
	x0_current = 0.2;
	draw(x0_current,r_current);

	function update(xy) {
		var x = xy[0];
		x0_current = xScaleInverse(x);
		var y = xy[1];
		r_current = 4*yScaleInverse(y);
		draw(x0_current, r_current);
	}
	svg
		.on("mousemove", function() {
			update(d3.mouse(this))
		})
		.on("mouseleave", function() {
			timer = d3.timer(trans);
		})
		.on("mouseenter", function() {
			if(window.timer && timer.stop) {
				timer.stop()
			}
		})

	function trans() {
		var rate = 0.7;
		var one_minus_rate = 1-rate;
		x0_current = rate*x0_current + one_minus_rate*0.2;
		r_current = rate*r_current + one_minus_rate*3;
		draw(x0_current, r_current)
		if(Math.abs(x0_current-0.2) + Math.abs(r_current-3)<0.001) {
			timer.stop()
			return false
		}
		else {
			return true
		}
	}

}
